@@ -11,12 +11,14 @@ import logging
 
 from oauth_dropins.webutil import util
 
+logger = logging.getLogger(__name__)
+
 # ActivityPub Content-Type details:
 # https://www.w3.org/TR/activitypub/#retrieving-objects
 CONTENT_TYPE = 'application/activity+json'
 CONTENT_TYPE_LD = 'application/ld+json; profile="https://www.w3.org/ns/activitystreams"'
 CONNEG_HEADERS = {
-    'Accept': '%s; q=0.9, %s; q=0.8' % (CONTENT_TYPE, CONTENT_TYPE_LD),
+    'Accept': f'{CONTENT_TYPE}; q=0.9, {CONTENT_TYPE_LD}; q=0.8',
 }
 CONTEXT = 'https://www.w3.org/ns/activitystreams'
 
@@ -72,7 +74,7 @@ def from_as1(obj, type=None, context=CONTEXT):
   if not obj:
     return {}
   elif not isinstance(obj, dict):
-    raise ValueError('Expected dict, got %r' % obj)
+    raise ValueError(f'Expected dict, got {obj!r}')
 
   obj = copy.deepcopy(obj)
 
@@ -130,8 +132,7 @@ def from_as1(obj, type=None, context=CONTEXT):
           obj['duration'] = util.to_iso8601_duration(
             datetime.timedelta(seconds=duration))
         except TypeError:
-          logging.warning('Dropping unexpected duration %r; expected int, is %s',
-                          duration, duration.__class__)
+          logger.warning(f'Dropping unexpected duration {duration!r}; expected int, is {duration.__class__}')
 
   loc = obj.get('location')
   if loc:
@@ -158,14 +159,15 @@ def to_as1(obj, use_type=True):
   elif isinstance(obj, str):
     return {'url': obj}
   elif not isinstance(obj, dict):
-    raise ValueError('Expected dict, got %r' % obj)
+    raise ValueError(f'Expected dict, got {obj!r}')
 
   obj = copy.deepcopy(obj)
-
   obj.pop('@context', None)
 
   type = obj.pop('type', None)
   if use_type:
+    if type and not isinstance(type, str):
+      raise ValueError(f'Expected type to be string, got {type!r}')
     obj['objectType'] = TYPE_TO_OBJECT_TYPE.get(type)
     obj['verb'] = TYPE_TO_VERB.get(type)
     if obj.get('inReplyTo') and obj['objectType'] in ('note', 'article'):
@@ -228,8 +230,7 @@ def to_as1(obj, use_type=True):
   attrib = util.pop_list(obj, 'attributedTo')
   if attrib:
     if len(attrib) > 1:
-      logging.warning('ActivityStreams 1 only supports single author; '
-                      'dropping extra attributedTo values: %s' % attrib[1:])
+      logger.warning(f'ActivityStreams 1 only supports single author; dropping extra attributedTo values: {attrib[1:]}')
     obj.setdefault('author', {}).update(to_as1(attrib[0]))
 
   return util.trim_nulls(obj)
