@@ -20,6 +20,8 @@ from oauth_dropins.webutil.util import json_dumps, json_loads
 
 from . import source
 
+logger = logging.getLogger(__name__)
+
 # Since API v2.4, we need to explicitly ask for the fields we want from most API
 # endpoints with ?fields=...
 # https://developers.facebook.com/docs/apps/changelog#v2_4_changes
@@ -223,7 +225,7 @@ class Facebook(source.Source):
 
   def object_url(self, id):
     # Facebook always uses www. They redirect bare facebook.com URLs to it.
-    return 'https://www.facebook.com/%s' % id
+    return f'https://www.facebook.com/{id}'
 
   user_url = object_url
 
@@ -274,7 +276,8 @@ class Facebook(source.Source):
 
     if self.scrape:
       return self._scrape_m(user_id=user_id, activity_id=activity_id,
-                            fetch_replies=fetch_replies, fetch_likes=fetch_likes)
+                            fetch_replies=fetch_replies, fetch_likes=fetch_likes,
+                            **kwargs)
 
     activities = []
 
@@ -286,7 +289,7 @@ class Facebook(source.Source):
         user_id, activity_id = activity_id.split('_', 1)
       post = self.urlopen(API_OBJECT % (user_id, activity_id))
       if post.get('error'):
-        logging.warning("Couldn't fetch object %s: %s", activity_id, post)
+        logger.warning(f"Couldn't fetch object {activity_id}: {post}")
         posts = []
       else:
         posts = [post]
@@ -404,8 +407,7 @@ class Facebook(source.Source):
       if obj_id:
         existing = posts_by_obj_id.get(obj_id)
         if existing:
-          logging.warning('merging posts for object_id %s: overwriting %s with %s!',
-                          obj_id, existing.get('id'), post.get('id'))
+          logger.warning(f"merging posts for object_id {obj_id}: overwriting {existing.get('id')} with {post.get('id')}!")
         posts_by_obj_id[obj_id] = post
 
     albums = None  # lazy loaded, maps facebook id to ActivityStreams object
@@ -485,13 +487,13 @@ class Facebook(source.Source):
       event = self.urlopen(API_EVENT % event_id)
 
     if not event or event.get('error'):
-      logging.warning("Couldn't fetch event %s: %s", event_id, event)
+      logger.warning(f"Couldn't fetch event {event_id}: {event}")
       return None
 
     event_owner_id = event.get('owner', {}).get('id')
     if owner_id and event_owner_id != owner_id:
-      logging.info('Ignoring event %s owned by user id %s instead of %s',
-                   event.get('name') or event.get('id'), event_owner_id, owner_id)
+      label = event.get('name') or event.get('id')
+      logger.info(f'Ignoring event {label} owned by user id {event_owner_id} instead of {owner_id}')
       return None
 
     return self.event_to_activity(event)
@@ -526,7 +528,7 @@ class Facebook(source.Source):
       share_id: string id of the share object
       activity: activity object (optional)
     """
-    orig_id = '%s_%s' % (activity_user_id, activity_id)
+    orig_id = f'{activity_user_id}_{activity_id}'
 
     # shares sometimes 400, not sure why.
     # https://github.com/snarfed/bridgy/issues/348
@@ -572,7 +574,7 @@ class Facebook(source.Source):
       activity: activity object (optional)
     """
     if '_' not in reaction_id:  # handle just name of reaction type
-      reaction_id = '%s_%s_by_%s' % (activity_id, reaction_id, reaction_user_id)
+      reaction_id = f'{activity_id}_{reaction_id}_by_{reaction_user_id}'
     return super(Facebook, self).get_reaction(
       activity_user_id, activity_id, reaction_user_id, reaction_id, activity=activity)
 
@@ -664,13 +666,12 @@ class Facebook(source.Source):
 
     url = obj.get('url')
     if include_link == source.INCLUDE_LINK and url:
-      content += '\n\n(Originally published at: %s)' % url
+      content += f'\n\n(Originally published at: {url})'
     preview_content = util.linkify(content)
     if video_url:
-      preview_content += ('<br /><br /><video controls src="%s"><a href="%s">'
-                          'this video</a></video>' % (video_url, video_url))
+      preview_content += f'<br /><br /><video controls src="{video_url}"><a href="{video_url}">this video</a></video>'
     elif image_url:
-      preview_content += '<br /><br /><img src="%s" />' % image_url
+      preview_content += f'<br /><br /><img src="{image_url}" />'
     if people:
       preview_content += '<br /><br /><em>with %s</em>' % ', '.join(
         '<a href="%s">%s</a>' % (
@@ -689,9 +690,8 @@ class Facebook(source.Source):
           '<a href="http://indiewebcamp.com/rel-syndication">rel-syndication</a> link to Facebook.')
 
       if preview:
-        desc = """\
-<span class="verb">comment</span> on <a href="%s">this post</a>:
-<br /><br />%s<br />""" % (base_url, self.embed_post(base_obj))
+        desc = f"""<span class="verb">comment</span> on <a href="{base_url}">this post</a>:
+<br /><br />{self.embed_post(base_obj)}<br />"""
         return source.creation_result(content=preview_content, description=desc)
       else:
         if image_url:
@@ -725,11 +725,9 @@ class Facebook(source.Source):
           author = comment.get('author', '')
           if author:
             author = self.embed_actor(author) + ':\n'
-          desc += '<a href="%s">this comment</a>:\n<br /><br />%s%s<br />' % (
-            base_url, author, comment.get('content'))
+          desc += f"<a href=\"{base_url}\">this comment</a>:\n<br /><br />{author}{comment.get('content')}<br />"
         else:
-          desc += '<a href="%s">this post</a>:\n<br /><br />%s<br />' % (
-            base_url, self.embed_post(base_obj))
+          desc += f'<a href="{base_url}">this post</a>:\n<br /><br />{self.embed_post(base_obj)}<br />'
         return source.creation_result(description=desc)
 
       else:
@@ -764,8 +762,7 @@ class Facebook(source.Source):
       # TODO: event invites
       if preview:
         assert verb.startswith('rsvp-')
-        desc = ('<span class="verb">RSVP %s</span> to <a href="%s">this event</a>.' %
-                (verb[5:], base_url))
+        desc = f'<span class="verb">RSVP {verb[5:]}</span> to <a href="{base_url}">this event</a>.'
         return source.creation_result(description=desc)
       else:
         resp = self.urlopen(RSVP_PUBLISH_ENDPOINTS[verb] % base_id, data='')
@@ -822,8 +819,8 @@ class Facebook(source.Source):
     else:
       return source.creation_result(
         abort=False,
-        error_plain='Cannot publish type=%s, verb=%s to Facebook' % (type, verb),
-        error_html='Cannot publish type=%s, verb=%s to Facebook' % (type, verb))
+        error_plain=f'Cannot publish type={type}, verb={verb} to Facebook',
+        error_html=f'Cannot publish type={type}, verb={verb} to Facebook')
 
     if 'url' not in resp:
       resp['url'] = base_url
@@ -869,18 +866,17 @@ class Facebook(source.Source):
 
     Raises: urllib2.HTPPError
     """
-    logging.debug('Sending Facebook notification: %r, %s', text, link)
+    logger.debug(f'Sending Facebook notification: {text!r}, {link}')
     params = {
       'template': text,
       'href': link,
       # this is a synthetic app access token.
       # https://developers.facebook.com/docs/facebook-login/access-tokens/#apptokens
-      'access_token': '%s|%s' % (oauth_dropins.facebook.FACEBOOK_APP_ID,
-                                 oauth_dropins.facebook.FACEBOOK_APP_SECRET),
+      'access_token': f'{oauth_dropins.facebook.FACEBOOK_APP_ID}|{oauth_dropins.facebook.FACEBOOK_APP_SECRET}',
     }
     url = API_BASE + API_NOTIFICATION % user_id
     resp = util.urlopen(urllib.request.Request(url, data=urllib.parse.urlencode(params)))
-    logging.debug('Response: %s %s', resp.getcode(), resp.read())
+    logger.debug(f'Response: {resp.getcode()} {resp.read()}')
 
   def post_url(self, post):
     """Returns a short Facebook URL for a post.
@@ -895,7 +891,7 @@ class Facebook(source.Source):
     id = self.parse_id(fb_id)
     author_id = id.user or post.get('from', {}).get('id')
     if author_id and id.post:
-      return 'https://www.facebook.com/%s/posts/%s' % (author_id, id.post)
+      return f'https://www.facebook.com/{author_id}/posts/{id.post}'
 
     return self.object_url(fb_id)
 
@@ -908,7 +904,7 @@ class Facebook(source.Source):
     """
     if post_author_id:
       post_id = post_author_id + '/posts/' + post_id
-    return 'https://www.facebook.com/%s?comment_id=%s' % (post_id, comment_id)
+    return f'https://www.facebook.com/{post_id}?comment_id={comment_id}'
 
   @classmethod
   def base_id(cls, url):
@@ -1016,10 +1012,10 @@ class Facebook(source.Source):
       if (base_id and '_' not in base_id and
           author.get('numeric_id') and not event_id):
         # add author user id prefix. https://github.com/snarfed/bridgy/issues/229
-        base_obj['id'] = '%s_%s' % (author['numeric_id'], base_id)
+        base_obj['id'] = f"{author['numeric_id']}_{base_id}"
 
     except BaseException as e:
-      logging.warning(
+      logger.warning(
         "Couldn't parse object URL %s : %s. Falling back to default logic.",
         url, e, exc_info=True)
 
@@ -1159,8 +1155,8 @@ class Facebook(source.Source):
     }) for t in tags]
 
     obj['tags'] += [self.postprocess_object({
-      'id': '%s_liked_by_%s' % (obj['id'], like.get('id')),
-      'url': url + '#liked-by-%s' % like.get('id'),
+      'id': f"{obj['id']}_liked_by_{like.get('id')}",
+      'url': url + f"#liked-by-{like.get('id')}",
       'objectType': 'activity',
       'verb': 'like',
       'object': {'url': url},
@@ -1174,8 +1170,8 @@ class Facebook(source.Source):
       if content:
         type = type.lower()
         obj['tags'].append(self.postprocess_object({
-          'id': '%s_%s_by_%s' % (obj['id'], type, id),
-          'url': url + '#%s-by-%s' % (type, id),
+          'id': f"{obj['id']}_{type}_by_{id}",
+          'url': url + f'#{type}-by-{id}',
           'objectType': 'activity',
           'verb': 'react',
           'content': content,
@@ -1315,7 +1311,7 @@ class Facebook(source.Source):
     return self.postprocess_object(obj)
 
   def _comment_id(self, post_id, comment_id):
-    return self.tag_uri('%s_%s' % (post_id, comment_id))
+    return self.tag_uri(f'{post_id}_{comment_id}')
 
   def share_to_object(self, share):
     """Converts a share (from /OBJECT/sharedposts) to an object.
@@ -1386,7 +1382,7 @@ class Facebook(source.Source):
       actor.update({
         'numeric_id': id,
         'image': {
-          'url': '%s%s/picture?type=large' % (API_BASE, id),
+          'url': f'{API_BASE}{id}/picture?type=large',
         },
       })
 
@@ -1480,8 +1476,8 @@ class Facebook(source.Source):
       user_id = rsvp.get('id')
       event_id = event.get('id')
       if event_id and user_id:
-        obj['id'] = self.tag_uri('%s_rsvp_%s' % (event_id, user_id))
-        obj['url'] = '%s#%s' % (self.object_url(event_id), user_id)
+        obj['id'] = self.tag_uri(f'{event_id}_rsvp_{user_id}')
+        obj['url'] = f'{self.object_url(event_id)}#{user_id}'
 
     return self.postprocess_object(obj)
 
@@ -1693,8 +1689,8 @@ class Facebook(source.Source):
         'objectType': 'activity',
         'verb': 'like',
         # TODO: handle author URLs for users without usernames
-        'id': self.tag_uri('%s_liked_by_%s' % (post_id, liker_id)),
-        'url': post_url + '#liked-by-%s' % liker_id,
+        'id': self.tag_uri(f'{post_id}_liked_by_{liker_id}'),
+        'url': post_url + f'#liked-by-{liker_id}',
         'object': {'url': post_url},
       })
 
@@ -1777,10 +1773,10 @@ class Facebook(source.Source):
       parsed = dateutil.parser.parse(tag.get_text(strip=True), default=now_fn())
       return parsed.isoformat('T')
     except (ValueError, OverflowError):
-      logging.debug("Couldn't parse datetime string %r", tag)
+      logger.debug(f"Couldn't parse datetime string {tag!r}")
 
   def _scrape_m(self, user_id=None, activity_id=None, fetch_replies=False,
-                fetch_likes=False):
+                fetch_likes=False, **kwargs):
     """Scrapes a user's timeline or a post and converts it to activities.
 
     Args:
@@ -1788,6 +1784,7 @@ class Facebook(source.Source):
       activity_id: string
       fetch_replies: boolean
       fetch_likes: boolean
+      kwargs: passed through to scraped_to_activit[y/ies]
 
     Returns:
       dict activities API response
@@ -1798,7 +1795,7 @@ class Facebook(source.Source):
 
     def get(url, *params):
       url = urllib.parse.urljoin(M_HTML_BASE_URL, url % params)
-      cookie = 'c_user=%s; xs=%s' % (self.cookie_c_user, self.cookie_xs)
+      cookie = f'c_user={self.cookie_c_user}; xs={self.cookie_xs}'
       resp = util.requests_get(url, allow_redirects=False, headers={
         'Cookie': cookie,
         'User-Agent': SCRAPE_USER_AGENT,
@@ -1808,10 +1805,10 @@ class Facebook(source.Source):
 
     if activity_id:
       resp = get(M_HTML_POST_URL, activity_id, user_id)
-      activities = [self.scraped_to_activity(resp.text)[0]]
+      activities = [self.scraped_to_activity(resp.text, **kwargs)[0]]
     else:
       resp = get(M_HTML_TIMELINE_URL, user_id)
-      activities, _ = self.scraped_to_activities(resp.text)
+      activities, _ = self.scraped_to_activities(resp.text, **kwargs)
       if fetch_replies:
         # fetch and convert individual post permalinks
         # TODO: cache?
@@ -1830,22 +1827,30 @@ class Facebook(source.Source):
 
     return self.make_activities_base_response(activities)
 
-  def scraped_to_activities(self, scraped, **kwargs):
+  def scraped_to_activities(self, scraped, log_html=False, **kwargs):
     """Converts HTML from an mbasic.facebook.com timeline to AS1 activities.
 
     Args:
       scraped: str, HTML
+      log_html: boolean
       kwargs: unused
 
     Returns: tuple: ([AS activities], AS logged in actor (ie viewer))
     """
     soup = util.parse_html(scraped)
+    if log_html:
+      logging.info(soup.prettify())
 
     activities = []
     for post in soup.find_all(('article', 'div'), id=re.compile('u_0_.+')):
       permalink = post.find(href=re.compile(r'^/story\.php\?'))
       if not permalink:
-        logging.debug('Skipping one due to missing permalink')
+        logger.debug('Skipping one due to missing permalink')
+        continue
+
+      header = post.find('header')
+      if header and 'Suggested for you' in header.stripped_strings:
+        logger.debug('Skipping "Suggested for you"')
         continue
 
       url = self._sanitize_url(urllib.parse.urljoin(self.BASE_URL, permalink['href']))
@@ -1856,13 +1861,13 @@ class Facebook(source.Source):
 
       author = self._m_html_author(post)
       if not author:
-        logging.debug('Skipping due to missing author')
+        logger.debug('Skipping due to missing author')
         continue
       author['id'] = self.tag_uri(owner_id)
 
       footer = post.footer
       if not footer:
-        logging.debug('Skipping due to missing footer')
+        logger.debug('Skipping due to missing footer')
         continue
 
       public = footer and ('Public' in footer.stripped_strings or
@@ -1942,16 +1947,19 @@ class Facebook(source.Source):
 
     return util.trim_nulls(activities), None
 
-  def scraped_to_activity(self, scraped):
+  def scraped_to_activity(self, scraped, log_html=False, **kwargs):
     """Converts HTML from an mbasic.facebook.com post page to an AS1 activity.
 
     Args:
       scraped: str, HTML from an mbasic.facebook.com post permalink
+      log_html: boolean
       kwargs: unused
 
     Returns: tuple: (dict AS activity or None, AS logged in actor (ie viewer))
     """
     soup = util.parse_html(scraped)
+    if log_html:
+      logging.info(soup.prettify())
 
     view = soup.find(id='m_story_permalink_view') or soup.find(id='MPhotoContent')
     if not view:
@@ -2110,8 +2118,8 @@ class Facebook(source.Source):
       tag = {
         'objectType': 'activity',
         'verb': 'like' if type == 'like' else 'react',
-        'id': self.tag_uri('%s_%s_by_%s' % (activity['fb_id'], type_str, username)),
-        'url': activity['url'] + '#%s-by-%s' % (type_str, username),
+        'id': self.tag_uri(f"{activity['fb_id']}_{type_str}_by_{username}"),
+        'url': activity['url'] + f'#{type_str}-by-{username}',
         'object': {'url': activity['url']},
         'author': author,
       }
@@ -2203,7 +2211,7 @@ class Facebook(source.Source):
     try:
       content = cls._div(tag, 0, 0)
     except IndexError:
-      logging.debug('Skipping due to non-post format (searching for content)')
+      logger.debug('Skipping due to non-post format (searching for content)')
       return ''
 
     if not content:
@@ -2241,7 +2249,7 @@ class Facebook(source.Source):
     Returns: list of AS1 attachment objects
     """
     atts = []
-    for link in tag.find_all('a', href=re.compile('^https://lm.facebook.com/l.php')):
+    for link in tag.find_all('a', href=re.compile(r'^https://lm\.facebook\.com/l\.php')):
       url = cls._unwrap_link(link)
       name = link.h3
       img = link.img
@@ -2296,6 +2304,9 @@ class Facebook(source.Source):
       return {}
 
     author = author.find('a')
+    url = author.get('href')
+    if not url:
+      return {}
     actor = self._profile_url_to_actor(author['href'])
     actor['displayName'] = author.get_text(' ', strip=True)
 
@@ -2450,7 +2461,7 @@ class Facebook(source.Source):
         fbid = blank
 
     if fbid == blank:
-      logging.error('Cowardly refusing Facebook id with unknown format: %s', id)
+      logger.error(f'Cowardly refusing Facebook id with unknown format: {id}')
 
     return fbid
 
@@ -2490,7 +2501,7 @@ class Facebook(source.Source):
       post = self.urlopen(API_OBJECT % (user_id, post_id))
       resolved = post.get('object_id')
       if resolved:
-        logging.info('Resolved Facebook post id %r to %r.', post_id, resolved)
+        logger.info(f'Resolved Facebook post id {post_id!r} to {resolved!r}.')
         return str(resolved)
 
   def urlopen(self, url, _as=dict, **kwargs):
@@ -2516,7 +2527,7 @@ class Facebook(source.Source):
     try:
       return self._as(_as, source.load_json(body, url))
     except ValueError:  # couldn't parse JSON
-      logging.debug('Response: %s %s', resp.getcode(), body)
+      logger.debug(f'Response: {resp.getcode()} {body}')
       raise
 
   @staticmethod
@@ -2538,12 +2549,12 @@ class Facebook(source.Source):
       if isinstance(resp, dict):
         resp = resp.get('data', [])
       else:
-        logging.warning('Expected dict response with `data` field, got %s', resp)
+        logger.warning(f'Expected dict response with `data` field, got {resp}')
 
     if isinstance(resp, type):
       return resp
     else:
-      logging.warning('Expected %s response, got %s', type, resp)
+      logger.warning(f'Expected {type} response, got {resp}')
       return type()
 
   def urlopen_batch(self, urls):
