@@ -19,16 +19,18 @@ import requests
 
 from . import source
 
-REST_API_BASE = 'https://api.github.com'
-REST_API_ISSUE = REST_API_BASE + '/repos/%s/%s/issues/%s'
-REST_API_CREATE_ISSUE = REST_API_BASE + '/repos/%s/%s/issues'
-REST_API_ISSUE_LABELS = REST_API_BASE + '/repos/%s/%s/issues/%s/labels'
-REST_API_COMMENTS = REST_API_BASE + '/repos/%s/%s/issues/%s/comments'
-REST_API_REACTIONS = REST_API_BASE + '/repos/%s/%s/issues/%s/reactions'
-REST_API_COMMENT = REST_API_BASE + '/repos/%s/%s/%s/comments/%s'
-REST_API_COMMENT_REACTIONS = REST_API_BASE + '/repos/%s/%s/%s/comments/%s/reactions'
-REST_API_MARKDOWN = REST_API_BASE + '/markdown'
-REST_API_NOTIFICATIONS = REST_API_BASE + '/notifications?all=true&participating=true'
+logger = logging.getLogger(__name__)
+
+REST_BASE = 'https://api.github.com'
+REST_ISSUE = REST_BASE + '/repos/%s/%s/issues/%s'
+REST_CREATE_ISSUE = REST_BASE + '/repos/%s/%s/issues'
+REST_ISSUE_LABELS = REST_BASE + '/repos/%s/%s/issues/%s/labels'
+REST_COMMENTS = REST_BASE + '/repos/%s/%s/issues/%s/comments'
+REST_REACTIONS = REST_BASE + '/repos/%s/%s/issues/%s/reactions'
+REST_COMMENT = REST_BASE + '/repos/%s/%s/%s/comments/%s'
+REST_COMMENT_REACTIONS = REST_BASE + '/repos/%s/%s/%s/comments/%s/reactions'
+REST_MARKDOWN = REST_BASE + '/markdown'
+REST_NOTIFICATIONS = REST_BASE + '/notifications?all=true&participating=true'
 GRAPHQL_BASE = 'https://api.github.com/graphql'
 GRAPHQL_BOT_FIELDS = 'id avatarUrl createdAt login url'
 GRAPHQL_ORG_FIELDS = 'id avatarUrl description location login name url websiteUrl'
@@ -273,14 +275,14 @@ class GitHub(source.Source):
     resp = util.requests_post(
       GRAPHQL_BASE, json={'query': graphql % escaped},
       headers={
-        'Authorization': 'bearer %s' % self.access_token,
+        'Authorization': f'bearer {self.access_token}',
       })
     resp.raise_for_status()
     result = json_loads(resp.text)
 
     errs = result.get('errors')
     if errs:
-      logging.warning(result)
+      logger.warning(result)
       raise ValueError('\n'.join(e.get('message') for e in errs))
 
     return result['data']
@@ -298,7 +300,7 @@ class GitHub(source.Source):
     """
     kwargs['headers'] = kwargs.get('headers') or {}
     kwargs['headers'].update({
-      'Authorization': 'token %s' % self.access_token,
+      'Authorization': f'token {self.access_token}',
       # enable the beta Reactions API
       # https://developer.github.com/v3/reactions/
       'Accept': 'application/vnd.github.squirrel-girl-preview+json',
@@ -352,7 +354,7 @@ class GitHub(source.Source):
       if len(parts) != 3:
         raise ValueError('GitHub activity ids must be of the form USER:REPO:ISSUE_OR_PR')
       try:
-        issue = self.rest(REST_API_ISSUE % parts)
+        issue = self.rest(REST_ISSUE % parts)
         activities = [self.issue_to_object(issue)]
       except BaseException as e:
         code, body = util.interpret_http_exception(e)
@@ -362,7 +364,7 @@ class GitHub(source.Source):
           raise
 
     else:
-      resp = self.rest(REST_API_NOTIFICATIONS, parse_json=False,
+      resp = self.rest(REST_NOTIFICATIONS, parse_json=False,
                        headers={'If-Modified-Since': etag} if etag else None)
       etag = resp.headers.get('Last-Modified')
       notifs = [] if resp.status_code == 304 else json_loads(resp.text)
@@ -371,11 +373,11 @@ class GitHub(source.Source):
         id = notif.get('id')
         subject_url = notif.get('subject').get('url')
         if not subject_url:
-          logging.info('Skipping thread %s, missing subject!', id)
+          logger.info(f'Skipping thread {id}, missing subject!')
           continue
         split = subject_url.split('/')
         if len(split) <= 2 or split[-2] not in ('issues', 'pulls'):
-          logging.info(
+          logger.info(
             'Skipping thread %s with subject %s, only issues and PRs right now',
             id, subject_url)
           continue
@@ -400,7 +402,7 @@ class GitHub(source.Source):
         comments_url = issue.get('comments_url')
         if fetch_replies and comments_url:
           if since:
-            comments_url += '?since=%s' % since.isoformat() + 'Z'
+            comments_url += f'?since={since.isoformat()}' + 'Z'
           comments = self.rest(comments_url)
           comment_objs = list(util.trim_nulls(
             self.comment_to_object(c) for c in comments))
@@ -451,7 +453,7 @@ class GitHub(source.Source):
     id = parts[-1]
     if util.is_int(id):  # REST API id
       parts.insert(2, 'issues')
-      comment = self.rest(REST_API_COMMENT % tuple(parts))
+      comment = self.rest(REST_COMMENT % tuple(parts))
     else:  # GraphQL node id
       comment = self.graphql(GRAPHQL_COMMENT, {'id': id})['node']
 
@@ -470,10 +472,10 @@ class GitHub(source.Source):
 
     Returns: unicode string, rendered HTML
     """
-    return self.rest(REST_API_MARKDOWN, {
+    return self.rest(REST_MARKDOWN, {
       'text': markdown,
       'mode': 'gfm',
-      'context': '%s/%s' % (owner, repo),
+      'context': f'{owner}/{repo}',
     }, parse_json=False).text
 
   def create(self, obj, include_link=source.OMIT_LINK, ignore_formatting=False):
@@ -539,7 +541,7 @@ class GitHub(source.Source):
     if type and type not in ('issue', 'comment', 'activity', 'note', 'article',
                              'like', 'tag'):
       return source.creation_result(
-        abort=False, error_plain='Cannot publish %s to GitHub' % type)
+        abort=False, error_plain=f'Cannot publish {type} to GitHub')
 
     base_obj = self.base_object(obj)
     base_url = base_obj.get('url')
@@ -553,7 +555,7 @@ class GitHub(source.Source):
       quote=False))
     url = obj.get('url')
     if include_link == source.INCLUDE_LINK and url:
-      content += '\n\n(Originally published at: %s)' % url
+      content += f'\n\n(Originally published at: {url})'
 
     parsed = urllib.parse.urlparse(base_url)
     path = parsed.path.strip('/').split('/')
@@ -572,8 +574,7 @@ class GitHub(source.Source):
     elif parsed.fragment:
       return source.creation_result(
         abort=True,
-        error_plain='Please remove the fragment #%s from your in-reply-to URL.' %
-          parsed.fragment)
+        error_plain=f'Please remove the fragment #{parsed.fragment} from your in-reply-to URL.')
 
     if type == 'comment':  # comment or reaction
       if not (len(path) == 4 and path[2] in ('issues', 'pull')):
@@ -583,10 +584,9 @@ class GitHub(source.Source):
       is_reaction = orig_content in REACTIONS_GRAPHQL
       if preview:
         if comment_id:
-          comment = self.rest(REST_API_COMMENT % (owner, repo, comment_type,
+          comment = self.rest(REST_COMMENT % (owner, repo, comment_type,
                                                   comment_id))
-          target_link = '<a href="%s">a comment on %s/%s#%s, <em>%s</em></a>' % (
-            base_url, owner, repo, number, util.ellipsize(comment['body']))
+          target_link = f"<a href=\"{base_url}\">a comment on {owner}/{repo}#{number}, <em>{util.ellipsize(comment['body'])}</em></a>"
         else:
           resp = self.graphql(GRAPHQL_ISSUE_OR_PR, locals())
           issue = (resp.get('repository') or {}).get('issueOrPullRequest')
@@ -596,11 +596,10 @@ class GitHub(source.Source):
 
         if is_reaction:
           preview_content = None
-          desc = u'<span class="verb">react %s</span> to %s.' % (
-            orig_content, target_link)
+          desc = f'<span class="verb">react {orig_content}</span> to {target_link}.'
         else:
           preview_content = self.render_markdown(content, owner, repo)
-          desc = '<span class="verb">comment</span> on %s:' % target_link
+          desc = f'<span class="verb">comment</span> on {target_link}:'
         return source.creation_result(content=preview_content, description=desc)
 
       else:  # create
@@ -610,19 +609,18 @@ class GitHub(source.Source):
         # https://github.com/snarfed/bridgy/issues/824
         if is_reaction:
           if comment_id:
-            api_url = REST_API_COMMENT_REACTIONS % (owner, repo, comment_type,
+            api_url = REST_COMMENT_REACTIONS % (owner, repo, comment_type,
                                                     comment_id)
             reacted = self.rest(api_url, data={
               'content': REACTIONS_REST.get(orig_content),
             })
             url = base_url
           else:
-            api_url = REST_API_REACTIONS % (owner, repo, number)
+            api_url = REST_REACTIONS % (owner, repo, number)
             reacted = self.rest(api_url, data={
               'content': REACTIONS_REST.get(orig_content),
             })
-            url = '%s#%s-by-%s' % (base_url, reacted['content'].lower(),
-                                   reacted['user']['login'])
+            url = f"{base_url}#{reacted['content'].lower()}-by-{reacted['user']['login']}"
 
           return source.creation_result({
             'id': reacted.get('id'),
@@ -632,7 +630,7 @@ class GitHub(source.Source):
 
         else:
           try:
-            api_url = REST_API_COMMENTS % (owner, repo, number)
+            api_url = REST_COMMENTS % (owner, repo, number)
             commented = self.rest(api_url, data={'body': content})
             return source.creation_result({
               'id': commented.get('id'),
@@ -649,8 +647,7 @@ class GitHub(source.Source):
 
       if preview:
         return source.creation_result(
-          description='<span class="verb">star</span> <a href="%s">%s/%s</a>.' %
-            (base_url, owner, repo))
+          description=f'<span class="verb">star</span> <a href="{base_url}">{owner}/{repo}</a>.')
 
       issue = self.graphql(GRAPHQL_REPO, locals())
       resp = self.graphql(GRAPHQL_ADD_STAR, {
@@ -673,19 +670,17 @@ class GitHub(source.Source):
 
       existing_labels = self.existing_labels(owner, repo)
       labels = sorted(tags & existing_labels)
-      issue_link = '<a href="%s">%s/%s#%s</a>' % (base_url, owner, repo, number)
+      issue_link = f'<a href="{base_url}">{owner}/{repo}#{number}</a>'
       if not labels:
         return source.creation_result(
           abort=True,
-          error_html="No tags in [%s] matched %s's existing labels [%s]." %
-            (', '.join(sorted(tags)), issue_link, ', '.join(sorted(existing_labels))))
+          error_html=f"No tags in [{', '.join(sorted(tags))}] matched {issue_link}'s existing labels [{', '.join(sorted(existing_labels))}].")
 
       if preview:
         return source.creation_result(
-          description='add label%s <span class="verb">%s</span> to %s.' % (
-            ('s' if len(labels) > 1 else ''), ', '.join(labels), issue_link))
+          description=f"add label{'s' if len(labels) > 1 else ''} <span class=\"verb\">{', '.join(labels)}</span> to {issue_link}.")
 
-      resp = self.rest(REST_API_ISSUE_LABELS % (owner, repo, number), labels)
+      resp = self.rest(REST_ISSUE_LABELS % (owner, repo, number), labels)
       return source.creation_result({
         'url': base_url,
         'type': 'tag',
@@ -704,17 +699,13 @@ class GitHub(source.Source):
       labels = sorted(tags & self.existing_labels(owner, repo))
 
       if preview:
-        preview_content = '<b>%s</b><hr>%s' % (
-          title, self.render_markdown(content, owner, repo))
+        preview_content = f'<b>{title}</b><hr>{self.render_markdown(content, owner, repo)}'
         preview_labels = ''
         if labels:
-          preview_labels = ' and attempt to add label%s <span class="verb">%s</span>' % (
-            's' if len(labels) > 1 else '', ', '.join(labels))
-        return source.creation_result(content=preview_content, description="""\
-<span class="verb">create a new issue</span> on <a href="%s">%s/%s</a>%s:""" %
-            (base_url, owner, repo, preview_labels))
+          preview_labels = f" and attempt to add label{'s' if len(labels) > 1 else ''} <span class=\"verb\">{', '.join(labels)}</span>"
+        return source.creation_result(content=preview_content, description=f"""<span class="verb">create a new issue</span> on <a href="{base_url}">{owner}/{repo}</a>{preview_labels}:""")
       else:
-        resp = self.rest(REST_API_CREATE_ISSUE % (owner, repo), {
+        resp = self.rest(REST_CREATE_ISSUE % (owner, repo), {
           'title': title,
           'body': content,
           'labels': labels,
@@ -724,7 +715,7 @@ class GitHub(source.Source):
 
     return source.creation_result(
       abort=False,
-      error_plain="%s doesn't look like a GitHub repo, issue, or PR URL." % base_url)
+      error_plain=f"{base_url} doesn't look like a GitHub repo, issue, or PR URL.")
 
   def existing_labels(self, owner, repo):
     """Fetches and returns a repo's labels.
@@ -776,7 +767,7 @@ class GitHub(source.Source):
       'inReplyTo': [{'url': in_reply_to}],
       'tags': [{
         'displayName': l['name'],
-        'url': '%s/labels/%s' % (repo_url, urllib.parse.quote(l['name'])),
+        'url': f"{repo_url}/labels/{urllib.parse.quote(l['name'])}",
       } for l in issue.get('labels', []) if l.get('name')],
     })
     return self.postprocess_object(obj)
@@ -834,8 +825,8 @@ class GitHub(source.Source):
     obj.update({
       'objectType': 'activity',
       'verb': 'react',
-      'id': target['id'] + '_%s_by_%s' % (enum, username),
-      'url': target['url'] + '#%s-by-%s' % (enum, username),
+      'id': target['id'] + f'_{enum}_by_{username}',
+      'url': target['url'] + f'#{enum}-by-{username}',
       'author': author,
       'content': content,
       'object': {'url': target['url']},
