@@ -7,6 +7,7 @@ https://groups.google.com/forum/m/#!topic/instagram-api-developers/DAO7OriVFsw
 https://groups.google.com/forum/#!searchin/instagram-api-developers/private
 """
 import datetime
+import itertools
 import logging
 import operator
 import re
@@ -20,6 +21,8 @@ import requests
 
 from . import source
 
+logger = logging.getLogger(__name__)
+
 # Maps Instagram media type to ActivityStreams objectType.
 OBJECT_TYPES = {'image': 'photo', 'video': 'video'}
 
@@ -42,12 +45,18 @@ HTML_PRELOAD_RE = re.compile(
 # the query hash here comes (i think) from inside a .js file served by IG, so
 # we'd have to fetch and scrape that to get it dynamically. not worth it yet.
 HTML_LIKES_URL = HTML_BASE_URL + 'graphql/query/?query_hash=d5d763b1e2acf209d62d22d184488e57&variables={"shortcode":"%s","include_reel":false,"first":100}'
+HTML_COMMENTS_URL = 'https://i.instagram.com/api/v1/media/%s/comments/?can_support_threading=true&permalink_enabled=false'
+
 HTML_DATA_RE = re.compile(r"""
   <script\ type="text/javascript">
   window\.(_sharedData\ =|__additionalDataLoaded\('[^']+',)\ *
   (.+?)
   \)?;</script>""", re.VERBOSE)
-HTML_USER_AGENT = 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10.15; rv:82.0) Gecko/20100101 Firefox/82.0'
+# duplicated in bridgy/browser-extension/instagram.js
+HEADERS = {
+  'User-Agent': 'Mozilla/5.0 (Macintosh; Intel Mac OS X 10.15; rv:96.0) Gecko/20100101 Firefox/96.0',
+  'X-IG-App-ID': '936619743392459',  # desktop web
+}
 
 # URL-safe base64 encoding. used in Instagram.id_to_shortcode()
 BASE64 = string.ascii_uppercase + string.ascii_lowercase + string.digits + '-_'
@@ -115,12 +124,12 @@ class Instagram(source.Source):
   @classmethod
   def user_url(cls, username):
     if username:
-      return '%s%s/' % (cls.BASE_URL, username)
+      return f'{cls.BASE_URL}{username}/'
 
   @classmethod
   def media_url(cls, shortcode):
     if shortcode:
-      return '%sp/%s/' % (cls.BASE_URL, shortcode)
+      return f'{cls.BASE_URL}p/{shortcode}/'
 
   def get_actor(self, user_id=None, **kwargs):
     """Returns a user as a JSON ActivityStreams actor dict.
@@ -168,7 +177,7 @@ class Instagram(source.Source):
     searching for them.
     https://github.com/snarfed/bridgy/issues/523#issuecomment-155523875
 
-    Shares are never fetched included since there is no share feature.
+    Shares are never fetched or included since there is no share feature.
 
     Instagram only supports search over hashtags, so if search_query is set, it
     must begin with #.
@@ -207,8 +216,7 @@ class Instagram(source.Source):
       if not ignore_rate_limit and _last_rate_limited:
         retry = _last_rate_limited + RATE_LIMIT_BACKOFF
         if now < retry:
-          logging.info('Remembered rate limit at %s, waiting until %s to try again.',
-                       _last_rate_limited, retry)
+          logger.info(f'Remembered rate limit at {_last_rate_limited}, waiting until {retry} to try again.')
           assert _last_rate_limited_exc
           raise _last_rate_limited_exc
 
@@ -219,7 +227,7 @@ class Instagram(source.Source):
       except Exception as e:
         code, body = util.interpret_http_exception(e)
         if not ignore_rate_limit and code in ('302', '401', '429', '503'):
-          logging.info('Got rate limited! Remembering for %s', str(RATE_LIMIT_BACKOFF))
+          logger.info(f'Got rate limited! Remembering for {RATE_LIMIT_BACKOFF}')
           _last_rate_limited = now
           _last_rate_limited_exc = e
         raise
@@ -275,7 +283,7 @@ class Instagram(source.Source):
         body_obj = {}
 
       if body_obj.get('meta', {}).get('error_type') == 'APINotFoundError':
-        logging.warning(body_obj.get('meta', {}).get('error_message'), exc_info=True)
+        logger.warning(body_obj.get('meta', {}).get('error_message'), exc_info=True)
       else:
         raise e
 
@@ -310,7 +318,7 @@ class Instagram(source.Source):
     if cookie:
       if not cookie.startswith('sessionid='):
         cookie = 'sessionid=' + cookie
-      get_kwargs['headers'] = {'Cookie': cookie, 'User-Agent': HTML_USER_AGENT}
+      get_kwargs['headers'] = {'Cookie': cookie, **HEADERS}
 
     resp = util.requests_get(url, **get_kwargs)
     location = resp.headers.get('Location', '')
@@ -346,8 +354,8 @@ class Instagram(source.Source):
         _, id = util.parse_tag_uri(activity['id'])
         likes = obj.get('ig_like_count') or 0
         comments = obj.get('replies', {}).get('totalItems') or 0
-        likes_key = 'AIL %s' % id
-        comments_key = 'AIC %s' % id
+        likes_key = f'AIL {id}'
+        comments_key = f'AIC {id}'
 
         if (likes and likes != cached.get(likes_key) or
             comments and comments != cached.get(comments_key)):
@@ -383,7 +391,7 @@ class Instagram(source.Source):
     if not activity:
       activity = self._get_activity(None, activity_id)
     if activity:
-      # TODO: unify with instagram, maybe in source.get_comment()
+      # TODO: unify with flickr, maybe in source.get_comment()
       tag_id = self.tag_uri(comment_id)
       for reply in activity.get('object', {}).get('replies', {}).get('items', []):
         if reply.get('id') == tag_id:
@@ -455,7 +463,7 @@ class Instagram(source.Source):
     base_id = base_obj.get('id')
     base_url = base_obj.get('url')
 
-    logging.debug(
+    logger.debug(
       'instagram create request with type=%s, verb=%s, id=%s, url=%s',
       type, verb, base_id, base_url)
 
@@ -471,8 +479,7 @@ class Instagram(source.Source):
       if preview:
         return source.creation_result(
           content=content,
-          description='<span class="verb">comment</span> on <a href="%s">'
-                      'this post</a>:\n%s' % (base_url, self.embed_post(base_obj)))
+          description=f'<span class="verb">comment</span> on <a href="{base_url}">this post</a>:\n{self.embed_post(base_obj)}')
 
       self.urlopen(API_COMMENT_URL % base_id, data=urllib.parse.urlencode({
         'access_token': self.access_token,
@@ -495,18 +502,16 @@ class Instagram(source.Source):
 
       if preview:
         return source.creation_result(
-          description='<span class="verb">like</span> <a href="%s">'
-                      'this post</a>:\n%s' % (base_url, self.embed_post(base_obj)))
+          description=f'<span class="verb">like</span> <a href="{base_url}">this post</a>:\n{self.embed_post(base_obj)}')
 
       if not base_id:
         shortcode = self.post_id(base_url)
-        logging.debug('looking up media by shortcode %s', shortcode)
+        logger.debug(f'looking up media by shortcode {shortcode}')
         media_entry = self.urlopen(API_MEDIA_SHORTCODE_URL % shortcode) or {}
         base_id = media_entry.get('id')
         base_url = media_entry.get('link')
 
-      logging.info('posting like for media id id=%s, url=%s',
-                   base_id, base_url)
+      logger.info(f'posting like for media id id={base_id}, url={base_url}')
       # no response other than success/failure
       self.urlopen(API_MEDIA_LIKES_URL % base_id, data=urllib.parse.urlencode({
         'access_token': self.access_token
@@ -569,10 +574,7 @@ class Instagram(source.Source):
       'author': self.user_to_actor(user),
       'content': content,
       'url': media.get('link'),
-      'to': [{
-        'objectType': 'group',
-        'alias': '@private' if user.get('is_private') else '@public',
-      }],
+      'to': self._is_private_to_to(user, default_public=True),
       'attachments': [{
         'objectType': 'video' if 'videos' in media else 'image',
         'url': media.get('link'),
@@ -607,7 +609,6 @@ class Instagram(source.Source):
        for u in media.get('users_in_photo', [])] +
       [self.like_to_object(u, id, media.get('link'))
        for u in media.get('likes', {}).get('data', [])] +
-
       self._mention_tags_from_content(content)
     }
 
@@ -621,14 +622,14 @@ class Instagram(source.Source):
 
     for version in ('standard_resolution', 'low_resolution', 'thumbnail'):
       image = media.get('images', {}).get(version)
-      if image:
-        object['image'] = {'url': image.get('url')}
+      if image and image.get('url'):
+        object['image'] = image
         break
 
     for version in ('standard_resolution', 'low_resolution', 'low_bandwidth'):
       video = media.get('videos', {}).get(version)
-      if video:
-        object['stream'] = {'url': video.get('url')}
+      if video and video.get('url'):
+        object['stream'] = video
         break
 
     # http://instagram.com/developer/endpoints/locations/
@@ -641,8 +642,7 @@ class Instagram(source.Source):
         'longitude': media_loc.get('point', {}).get('longitude'),
         'address': {'formatted': media_loc.get('street_address')},
         'url': (media_loc.get('id')
-                and 'https://instagram.com/explore/locations/%s/'
-                % media_loc.get('id')),
+                and f"https://instagram.com/explore/locations/{media_loc.get('id')}/"),
       }
 
     return self.postprocess_object(object)
@@ -673,7 +673,7 @@ class Instagram(source.Source):
       'objectType': 'comment',
       'id': self.tag_uri(comment.get('id')),
       'inReplyTo': [{'id': self.tag_uri(media_id)}],
-      'url': '%s#comment-%s' % (media_url, comment.get('id')) if media_url else None,
+      'url': f"{media_url}#comment-{comment.get('id')}" if media_url else None,
       # TODO: add PST time zone
       'published': util.maybe_timestamp_to_rfc3339(comment.get('created_time')),
       'content': content,
@@ -693,13 +693,16 @@ class Instagram(source.Source):
     Returns:
       an ActivityStreams object dict, ready to be JSON-encoded
     """
+    id = liker.get('id')  # v1
+    pk = liker.get('pk')  # v2
+
     return self.postprocess_object({
-        'id': self.tag_uri('%s_liked_by_%s' % (media_id, liker.get('id'))),
-        'url': '%s#liked-by-%s' % (media_url, liker.get('id')) if media_url else None,
+        'id': self.tag_uri(f"{media_id}_liked_by_{id or pk}"),
+        'url': f"{media_url}#liked-by-{id or pk}" if media_url else None,
         'objectType': 'activity',
         'verb': 'like',
         'object': {'url': media_url},
-        'author': self.user_to_actor(liker),
+        'author': self.user_to_actor(liker) if id else self._feed_v2_user_to_actor(liker),
     })
 
   def user_to_actor(self, user):
@@ -720,9 +723,8 @@ class Instagram(source.Source):
       'id': self.tag_uri(id or username),
       'username': username,
       'objectType': 'person',
+      'to': self._is_private_to_to(user),
     }
-    if not id or not username:
-      return actor
 
     urls = [self.user_url(username)] + sum(
       (util.extract_links(user.get(field)) for field in ('website', 'bio')), [])
@@ -731,13 +733,6 @@ class Instagram(source.Source):
       'urls': [{'value': u} for u in urls] if len(urls) > 1 else None
     })
 
-    private = user.get('is_private')
-    if private is not None:
-      actor['to'] = [{
-        'objectType': 'group',
-        'alias': '@private' if private else '@public',
-      }]
-
     pic_url = user.get('profile_picture') or user.get('profile_pic_url') or ''
 
     actor.update({
@@ -788,6 +783,17 @@ class Instagram(source.Source):
 
     return ''.join(reversed(chars))
 
+  @staticmethod
+  def _is_private_to_to(obj, default_public=False):
+    """Generates an AS 'to' field from an Instagram 'is_private' field."""
+    private = obj.get('is_private')
+    if private is not None or default_public:
+      return [{
+        'objectType': 'group',
+        'alias': '@private' if private else '@public',
+      }]
+
+
   def scraped_to_activities(self, html, cookie=None, count=None,
                             fetch_extras=False):
     """Converts scraped Instagram HTML to ActivityStreams activities.
@@ -815,11 +821,12 @@ class Instagram(source.Source):
     if not matches:
       # Instagram sometimes returns 200 with incomplete HTML. often it stops at
       # the end of one of the <style> tags inside <head>. not sure why.
-      logging.warning('JSON script tag not found!')
+      logger.warning('JSON script tag not found!')
       return [], None
 
     # find media
     medias = []
+    feed_v2_items = []
     profile_user = None
     viewer_user = None
 
@@ -835,6 +842,10 @@ class Instagram(source.Source):
                       if e.get('node', {}).get('__typename') not in
                       ('GraphSuggestedUserFeedUnit',))
 
+      # feed v2
+      feed_v2_items.extend(data.get('feed_items', []))
+      feed_v2_items.extend(data.get('items', []))
+
       if 'user' in data:
         edges = data['user'].get('edge_web_feed_timeline', {}).get('edges', [])
         medias.extend(e.get('node') for e in edges)
@@ -855,7 +866,7 @@ class Instagram(source.Source):
         if media:
           medias.append(media)
 
-    if not medias:
+    if not medias and not feed_v2_items:
       # As of 2018-02-15, embedded JSON in logged in https://www.instagram.com/
       # no longer has any useful data. Need to do a second header link fetch.
       soup = util.parse_html(html)
@@ -871,19 +882,43 @@ class Instagram(source.Source):
       medias = medias[:count]
 
     activities = []
+
     for media in util.trim_nulls(medias):
       activity = self._json_media_node_to_activity(media, user=profile_user)
 
-      # likes
+      # extra GraphQL fetch for likes
       shortcode = media.get('code') or media.get('shortcode')
       likes = media.get('edge_media_preview_like') or {}
-      if shortcode and fetch_extras and likes.get('count') and not likes.get('edges'):
-        # extra GraphQL fetch to get likes, as of 8/2018
+      if (shortcode and fetch_extras and likes.get('count') and
+          len(likes.get('edges', [])) < likes.get('count')):
         likes_json = self._scrape_json(HTML_LIKES_URL % shortcode, cookie=cookie)
         self.merge_scraped_reactions(likes_json, activity)
 
       activities.append(util.trim_nulls(activity))
 
+    for item in feed_v2_items:
+      media = item.get('media_or_ad') or item
+      if media and (not count or len(activities) < count):
+        activity = self._feed_v2_item_to_activity(media)
+        self.merge_scraped_comments(media, activity)
+        self.merge_scraped_reactions({'data': {'shortcode_media': media}}, activity)
+
+        # extra API fetch for comments
+        pk = media.get('pk')
+        if (pk and fetch_extras and media.get('comment_count') and
+            not media.get('comments')):
+          comments_json = self._scrape_json(HTML_COMMENTS_URL % pk, cookie=cookie)
+          self.merge_scraped_comments(comments_json, activity)
+
+        # extra GraphQL fetch for likes
+        shortcode = activity['object'].get('ig_shortcode')
+        if (shortcode and fetch_extras and media.get('like_count') and
+            not media.get('likers')):
+          likes_json = self._scrape_json(HTML_LIKES_URL % shortcode, cookie=cookie)
+          self.merge_scraped_reactions(likes_json, activity)
+
+        activities.append(util.trim_nulls(activity))
+
     user = self._json_user_to_user(viewer_user or profile_user)
     actor = self.user_to_actor(user) if user else None
     return activities, actor
@@ -913,12 +948,63 @@ class Instagram(source.Source):
     """
     return self.scraped_to_activities(html, **kwargs)[1]
 
+  def merge_scraped_comments(self, scraped, activity):
+    """Converts and merges scraped comments (replies) into an activity.
+
+    Args:
+      scraped: str or sequence, scraped JSON comments
+      activity: dict, AS activity to merge these comments into
+
+    Returns:
+      list of dict AS comment objects converted from scraped
+
+    Raises:
+      ValueError: if scraped is not valid JSON
+    """
+    if isinstance(scraped, str):
+      scraped = json_loads(scraped)
+
+    obj = activity['object']
+    url = obj.get('url') or activity.get('url')
+    obj_id = obj.get('id') or activity.get('id')
+
+    replies = []
+    for cmt in scraped.get('comments') or []:
+      cmt_id = self.tag_uri(cmt.get('pk'))
+      content = cmt.get('text') or ''
+      reply = {
+        'objectType': 'comment',
+        'id': cmt_id,
+        'url': f"{url}#comment-{cmt.get('pk')}" if url else None,
+        'author': self._feed_v2_user_to_actor(cmt.get('user')),
+        'content': content,
+        'published': util.maybe_timestamp_to_rfc3339(cmt.get('created_at')),
+        'inReplyTo': [{'id': obj_id}],
+        'tags': self._mention_tags_from_content(content),
+        'to': [{'objectType': 'group', 'alias': '@public'}],
+      }
+      parent = cmt.get('parent_comment_id')
+      if parent:
+        reply['inReplyTo'].append({'id': cmt_id})
+      replies.append(util.trim_nulls(reply))
+
+    obj_replies = obj.setdefault('replies', {})
+    if replies:
+      source.merge_by_id(obj_replies, 'items', replies)
+
+    obj_replies['totalItems'] = max(scraped.get('comment_count', 0),
+                                    obj_replies.get('totalItems', 0),
+                                    len(obj_replies.get('items', [])))
+    return replies
+
   def merge_scraped_reactions(self, scraped, activity):
     """Converts and merges scraped likes and reactions into an activity.
 
     New likes and emoji reactions are added to the activity in 'tags'.
     Existing likes and emoji reactions in 'tags' are ignored.
 
+    Supports both legacy and v2 Instagram JSON.
+
     Args:
       scraped: str or dict, scraped JSON likes
       activity: dict, AS activity to merge these reactions into
@@ -935,11 +1021,16 @@ class Instagram(source.Source):
     media = scraped.get('data', {}).get('shortcode_media', {})
     if media:
       id = util.parse_tag_uri(activity['id'])[1]
-      media_url = self.media_url(media['shortcode'])
-      likes = [self.like_to_object(like.get('node', {}), id, media_url)
-               for like in media.get('edge_liked_by', {}).get('edges', [])]
-      source.merge_by_id(activity['object'], 'tags', likes)
-      return likes
+      obj = activity['object']
+      shortcode = media.get('shortcode')
+      media_url = self.media_url(shortcode) if shortcode else obj.get('url')
+      likers = [l.get('node', {}) for l in
+                media.get('edge_liked_by', {}).get('edges', [])]  # v1
+      likers.extend(media.get('likers', []))  # v2
+      like_tags = util.trim_nulls(
+        [self.like_to_object(l, id, media_url) for l in likers])
+      source.merge_by_id(obj, 'tags', like_tags)
+      return like_tags
 
     return []
 
@@ -950,7 +1041,7 @@ class Instagram(source.Source):
     if cookie:
       if not cookie.startswith('sessionid='):
         cookie = 'sessionid=' + cookie
-      headers = {'Cookie': cookie, 'User-Agent': HTML_USER_AGENT}
+      headers = {'Cookie': cookie, **HEADERS}
 
     resp = util.requests_get(url, allow_redirects=False, headers=headers)
     resp.raise_for_status()
@@ -958,8 +1049,8 @@ class Instagram(source.Source):
     try:
       return json_loads(resp.text)
     except ValueError:
-      msg = "Couldn't decode response as JSON:\n%s" % resp.text
-      logging.error(msg, exc_info=True)
+      msg = f"Couldn't decode response as JSON:\n{resp.text}"
+      logger.error(msg, exc_info=True)
       resp.status_code = 504
       raise requests.HTTPError('504 Bad response from Instagram\n' + msg,
                                response=resp)
@@ -1003,7 +1094,7 @@ class Instagram(source.Source):
     id = media.get('id')
     owner_id = owner.get('id')
     if id and owner_id:
-      media['id'] = '%s_%s' % (id, owner_id)
+      media['id'] = f'{id}_{owner_id}'
 
     comments_edge = (media.get('comments') or media.get('edge_media_to_comment') or
                      media.get('edge_media_to_parent_comment') or {})
@@ -1066,6 +1157,123 @@ class Instagram(source.Source):
     self.postprocess_object(obj)
     return super(Instagram, self).postprocess_activity(activity)
 
+  def _feed_v2_user_to_actor(self, user):
+    if not user:
+      return {}
+
+    username = user.get('username')
+    return {
+      'objectType': 'person',
+      'id': self.tag_uri(user.get('pk') or username),
+      'username': user.get('username'),
+      'url': self.user_url(username),
+      'displayName': user.get('full_name') or username,
+      'image': {'url': user.get('profile_pic_url')},
+      'to': self._is_private_to_to(user),
+    }
+
+  def _feed_v2_item_to_activity(self, item):
+    """Converts Instagram HTML JSON feed_v2 item to ActivityStreams activity.
+
+    Note that this ignores comments and likes! See
+    :meth:`Instagram.merge_scraped_comments`, :meth:`Instagram.merge_scraped_reactions`,
+    and the end of :meth:`Instagram.scraped_to_activities` for those.
+
+    Args:
+      media: dict, item from a feed_v2 JSON
+
+    Returns:
+      dict, ActivityStreams activity
+    """
+    user = item.get('user') or {}
+    actor = self._feed_v2_user_to_actor(user)
+
+    item_pk = item.get("pk")
+    user_pk = user.get("pk")
+    obj_id = self.tag_uri(f'{item_pk}_{user_pk}' if user_pk else item_pk)
+
+    media_url = self.media_url(item.get('code'))
+    caption = item.get('caption', {})
+
+    # media
+    attachments = []
+    image = stream = None
+    for media in (item.get('carousel_media') or [item]):
+      image = None
+      images = media.get('image_versions2', {}).get('candidates')
+      if images:
+        image = max(images, key=operator.itemgetter('width'))
+
+      if media.get('video_versions'):
+        stream = max(
+            ({k: v for k, v in vid.items() if k in ('url', 'width', 'height')}
+             for vid in media['video_versions']),
+            key=operator.itemgetter('width'))
+        attachments.append({
+          'objectType': 'video',
+          'url': media_url,
+          'stream': [stream],
+          'image': [image],
+        })
+
+      elif image:
+        attachments.append({
+          'objectType': 'image',
+          'url': media_url,
+          'image': [image],
+        })
+
+    # object
+    content = caption.get('text') or ''
+    obj = {
+      'id': obj_id,
+      'ig_shortcode': item.get('code'),
+      'objectType': 'video' if stream else 'photo' if image else None,
+      'url': media_url,
+      'author': actor,
+      'content': content,
+      'published': util.maybe_timestamp_to_rfc3339(
+        caption.get('created_at') or item.get('taken_at')),
+      'to': actor.get('to'),
+      'attachments': attachments,
+      'image': image,
+      'stream': stream,
+      'ig_like_count': item.get('like_count'),
+    }
+
+    # person tags and mentions
+    obj['tags'] = list(util.trim_nulls(
+      self._feed_v2_user_to_actor(tag.get('user')) for tag in
+      itertools.chain(*item.get('usertags', {}).values())))
+    obj['tags'].extend(self._mention_tags_from_content(content))
+
+    # location
+    loc = item.get('location')
+    if loc:
+      loc_pk = loc.get('pk')
+      obj['location'] = {
+        'id': self.tag_uri(loc_pk),
+        'displayName': loc.get('name') or loc.get('short_name'),
+        'latitude': loc.get('lat'),
+        'longitude': loc.get('lng'),
+        'address': {'formatted': loc.get('address')},
+        'url': (f'https://instagram.com/explore/locations/{loc_pk}/'
+                if loc_pk else None),
+      }
+
+    # activity
+    activity = {
+      'verb': 'post',
+      'id': obj['id'],
+      'url': media_url,
+      'published': obj['published'],
+      'object': obj,
+      'actor': actor,
+    }
+
+    self.postprocess_object(obj)
+    return super(Instagram, self).postprocess_activity(activity)
+
   def _json_user_to_user(self, user):
     """Converts an Instagram HTML JSON user to an API actor.
 
