@@ -15,12 +15,16 @@ from datetime import datetime, time
 import logging
 import mimetypes
 
+import dateutil.parser
 from feedgen.feed import FeedGenerator
+import feedparser
 import mf2util
 from oauth_dropins.webutil import util
 
 from . import microformats2
 
+logger = logging.getLogger(__name__)
+
 # allowed ActivityStreams objectTypes for media enclosures
 ENCLOSURE_TYPES = {'audio', 'video'}
 
@@ -141,8 +145,7 @@ def from_activities(activities, actor=None, title=None, feed_url=None,
       if (att.get('objectType') in ENCLOSURE_TYPES or
           mime and mime.split('/')[0] in ENCLOSURE_TYPES):
         if item_has_enclosure:
-          logging.info('Warning: item %s already has an RSS enclosure, skipping additional enclosure %s',
-                       id, url)
+          logger.info(f'Warning: item {id} already has an RSS enclosure, skipping additional enclosure {url}')
           continue
 
         item_has_enclosure = feed_has_enclosure = True
@@ -170,3 +173,87 @@ def from_activities(activities, actor=None, title=None, feed_url=None,
     fg.lastBuildDate(latest)
 
   return fg.rss_str(pretty=True).decode('utf-8')
+
+
+def to_activities(rss):
+  """Converts an RSS feed to ActivityStreams 1 activities.
+
+  Args:
+    rss: unicode string, RSS document with top-level <rss> element
+
+  Returns:
+    list of ActivityStreams activity dicts
+  """
+  parsed = feedparser.parse(rss)
+  activities = []
+
+  feed = parsed.get('feed', {})
+  actor = {
+    'displayName': feed.get('title'),
+    'url': feed.get('link'),
+    'summary': feed.get('info') or feed.get('description'),
+    'image': [{'url': feed.get('image', {}).get('href') or feed.get('logo')}],
+  }
+
+  def iso_datetime(field):
+    # check for existence because feedparser returns 'published' for 'updated'
+    # when you [] or .get() it
+    if field in entry:
+      try:
+        return dateutil.parser.parse(entry[field]).isoformat()
+      except (TypeError, dateutil.parser.ParserError):
+        return None
+
+  def as_int(val):
+    return int(val) if util.is_int(val) else val
+
+  for entry in parsed.get('entries', []):
+    id = entry.get('id')
+    uri = entry.get('uri') or entry.get('link')
+
+    attachments = []
+    for e in entry.get('enclosures', []):
+      url = e.get('href')
+      if url:
+        mime = e.get('type') or mimetypes.guess_type(url)[0] or ''
+        type = mime.split('/')[0]
+        attachments.append({
+          'stream': {
+            'url': url,
+            'size': as_int(e.get('length')),
+            'duration': as_int(entry.get('itunes_duration')),
+          },
+          'objectType': type if type in ENCLOSURE_TYPES else None,
+        })
+
+    detail = entry.get('author_detail', {})
+    author = util.trim_nulls({
+      'displayName': detail.get('name') or entry.get('author'),
+      'url': detail.get('href'),
+      'email': detail.get('email'),
+    })
+    if not author:
+      author = actor
+
+    activities.append({
+      'objectType': 'activity',
+      'verb': 'create',
+      'id': id,
+      'url': uri,
+      'actor': author,
+      'object': {
+        'objectType': 'article',
+        'id': id or uri,
+        'url': uri,
+        'displayName': entry.get('title'),
+        'content': entry.get('content', [{}])[0].get('value') or entry.get('description'),
+        'published': iso_datetime('published'),
+        'updated': iso_datetime('updated'),
+        'author': author,
+        'tags': [{'displayName': tag.get('term') for tag in entry.get('tags', [])}],
+        'attachments': attachments,
+        'stream': [a['stream'] for a in attachments],
+      },
+    })
+
+  return util.trim_nulls(activities)
