@@ -23,6 +23,8 @@ import html2text
 from oauth_dropins.webutil import util
 from oauth_dropins.webutil.util import json_dumps, json_loads
 
+logger = logging.getLogger(__name__)
+
 APP = '@app'
 ME = '@me'
 SELF = '@self'
@@ -111,8 +113,8 @@ def load_json(body, url):
   try:
     return json_loads(body)
   except (ValueError, TypeError):
-    msg = 'Non-JSON response! Returning synthetic HTTP 502.\n%s' % body
-    logging.error(msg)
+    msg = f'Non-JSON response! Returning synthetic HTTP 502.\n{body}'
+    logger.error(msg)
     raise urllib.error.HTTPError(url, 502, msg, {}, None)
 
 
@@ -244,8 +246,8 @@ class Source(object, metaclass=SourceMeta):
       self, user_id=None, group_id=None, app_id=None, activity_id=None,
       start_index=0, count=0, etag=None, min_id=None, cache=None,
       fetch_replies=False, fetch_likes=False, fetch_shares=False,
-      fetch_events=False, fetch_mentions=False, search_query=None, scrape=False,
-      **kwargs):
+      include_shares=True, fetch_events=False, fetch_mentions=False,
+      search_query=None, scrape=False, **kwargs):
     """Fetches and returns ActivityStreams activities and response details.
 
     Subclasses should override this. See :meth:`get_activities()` for an
@@ -284,6 +286,7 @@ class Source(object, metaclass=SourceMeta):
         Used to cache data that's expensive to regenerate, e.g. API calls.
       fetch_replies: boolean, whether to fetch each activity's replies also
       fetch_likes: boolean, whether to fetch each activity's likes also
+      include_shares: boolean, whether to include share activities
       fetch_shares: boolean, whether to fetch each activity's shares also
       fetch_events: boolean, whether to fetch the user's events also
       fetch_mentions: boolean, whether to fetch posts that mention the user
@@ -663,9 +666,8 @@ class Source(object, metaclass=SourceMeta):
         elif verb and (obj_name or obj_type):
           app = activity.get('generator', {}).get('displayName')
           name = obj_name or 'a %s' % (obj_type or 'unknown')
-          app = ' on %s' % app if app else ''
-          activity['title'] = '%s %s %s%s.' % (actor_name, verb or 'posted',
-                                               name, app)
+          app = f' on {app}' if app else ''
+          activity['title'] = f"{actor_name} {verb or 'posted'} {name}{app}."
 
     return util.trim_nulls(activity)
 
@@ -779,8 +781,7 @@ class Source(object, metaclass=SourceMeta):
       if redirected_from and include_redirect_sources:
         which.add(redirected_from)
 
-    logging.info('Original post discovery found original posts %s, mentions %s',
-                 originals, mentions)
+    logger.info(f'Original post discovery found original posts {originals}, mentions {mentions}')
     return originals, mentions
 
   @staticmethod
@@ -858,7 +859,7 @@ class Source(object, metaclass=SourceMeta):
 
         if event_id and 'id' in actor:
           _, actor_id = util.parse_tag_uri(actor['id'])
-          rsvp['id'] = util.tag_uri(domain, '%s_rsvp_%s' % (event_id, actor_id))
+          rsvp['id'] = util.tag_uri(domain, f'{event_id}_rsvp_{actor_id}')
           if url:
             rsvp['url'] = '#'.join((url, actor_id))
 
@@ -892,7 +893,7 @@ class Source(object, metaclass=SourceMeta):
       a_val = a.get(field)
       if b_val != a_val and (a_val or b_val):
         if log:
-          logging.debug('%s[%s] %s => %s', label, field, b_val, a_val)
+          logger.debug(f'{label}[{field}] {b_val} => {a_val}')
         return True
 
     obj_b = before.get('object', {})
@@ -944,12 +945,9 @@ class Source(object, metaclass=SourceMeta):
   @classmethod
   def embed_actor(cls, actor):
     """Returns the HTML string for embedding an actor object."""
-    return """
-<a class="h-card" href="%s">
- <img class="profile u-photo" src="%s" width="32px" /> %s</a>""" % (
-     actor.get('url'),
-     actor.get('image', {}).get('url'),
-     actor.get('displayName'))
+    return f"""
+<a class="h-card" href="{actor.get('url')}">
+ <img class="profile u-photo" src="{actor.get('image', {}).get('url')}" width="32px" /> {actor.get('displayName')}</a>"""
 
   def tag_uri(self, name):
     """Returns a tag URI string for this source and the given string name."""
