@@ -10,11 +10,13 @@ from oauth_dropins.webutil.util import json_dumps, json_loads
 
 from .. import as2, jsonfeed, microformats2, rss
 
+logger = logging.getLogger(__name__)
+
 
 def filepairs(ext1, ext2s):
   """Returns all matching pairs of filenames with the given extensions."""
   pairs = []
-  for first in glob.glob('*.%s' % ext1):
+  for first in glob.glob(f'*.{ext1}'):
     for ext2 in ext2s:
       second = first[:-len(ext1)] + ext2
       if os.path.isfile(second):
@@ -28,10 +30,10 @@ def read_json(filename):
   try:
     with open(filename, encoding='utf-8') as f:
       # note that ujson allows embedded newlines in strings, which we have in eg
-      # note_with_whitespace.as.json and frriends.
+      # note_with_whitespace.as.json and friends.
       return json_loads(f.read())
   except Exception as e:
-    e.args = ('%s: ' % filename,) + e.args
+    e.args = (f'{filename}: ',) + e.args
     raise
 
 
@@ -86,6 +88,9 @@ def rss_from_activities(activities):
     activities, actor=ACTOR, title='Stuff', feed_url='http://site/feed',
     home_page_url='http://site/', hfeed=hfeed)
 
+def rss_to_objects(feed):
+  return [a['object'] for a in rss.to_activities(feed)]
+
 # source extension, destination extension, conversion function, exclude prefix.
 # destinations take precedence in the order they appear. only the first (source,
 # dest) pair for a given prefix is tested. this is how eg mf2-from-as.json gets
@@ -108,6 +113,7 @@ mappings = (
   ('as.json', ['as2-from-as.json', 'as2.json'], as2.from_as1, ()),
   ('as2.json', ['as-from-as2.json', 'as.json'], as2.to_as1, ()),
   ('as.json', ['rss.xml'], rss_from_activities, ()),
+  ('rss.xml', ['as-from-rss.json', 'as.json'], rss_to_objects, ()),
 )
 
 test_funcs = {}
@@ -119,7 +125,7 @@ for src_ext, dst_exts, fn, excludes in mappings:
     expected = read(dst)
     original = read(src)
     test_name = (
-      'test_%s_%s' % (fn.__name__, src[:-len(src_ext)])
+      f'test_{fn.__name__}_{src[:-len(src_ext)]}'
     ).replace('.', '_').replace('-', '_').strip('_')
     test_funcs[test_name] = create_test_function(fn, original, expected)
 
