@@ -25,6 +25,8 @@ from requests import RequestException
 
 from . import source
 
+logger = logging.getLogger(__name__)
+
 # common to all API calls that fetch tweets
 API_TWEET_PARAMS = '&include_entities=true&tweet_mode=extended&include_ext_alt_text=true'
 
@@ -196,8 +198,9 @@ class Twitter(source.Source):
                               activity_id=None, start_index=0, count=0,
                               etag=None, min_id=None, cache=None,
                               fetch_replies=False, fetch_likes=False,
-                              fetch_shares=False, fetch_events=False,
-                              fetch_mentions=False, search_query=None, **kwargs):
+                              fetch_shares=False, include_shares=False,
+                              fetch_events=False, fetch_mentions=False,
+                              search_query=None, scrape=False, **kwargs):
     """Fetches posts and converts them to ActivityStreams activities.
 
     XXX HACK: this is currently hacked for bridgy to NOT pass min_id to the
@@ -339,7 +342,7 @@ class Twitter(source.Source):
     cached = {}
     if cache is not None:
       keys = itertools.product(('ATR', 'ATF'), [t['id_str'] for t in tweets])
-      cached = cache.get_multi('%s %s' % (prefix, id) for prefix, id in keys)
+      cached = cache.get_multi(f'{prefix} {id}' for prefix, id in keys)
     # only update the cache at the end, in case we hit an error before then
     cache_updates = {}
 
@@ -353,8 +356,7 @@ class Twitter(source.Source):
         if tweet.get('retweeted') or tweet.get('user', {}).get('protected'):
           continue
         elif retweet_calls >= RETWEET_LIMIT:
-          logging.warning("Hit Twitter's retweet rate limit (%d) with more to "
-                          "fetch! Results will be incomplete!" % RETWEET_LIMIT)
+          logger.warning(f"Hit Twitter's retweet rate limit ({RETWEET_LIMIT}) with more to fetch! Results will be incomplete!")
           break
 
         # store retweets in the 'retweets' field, which is handled by
@@ -391,6 +393,9 @@ class Twitter(source.Source):
           retweet_calls += 1
           cache_updates['ATR ' + id] = count
 
+    if not include_shares:
+      tweets = [t for t in tweets if not t.get('retweeted_status')]
+
     tweet_activities = [self.tweet_to_activity(t) for t in tweets]
 
     if fetch_replies:
@@ -725,11 +730,10 @@ class Twitter(source.Source):
       url = self.URL_CANONICALIZER(att.get('url', ''))
       if url and TWEET_URL_RE.match(url):
         quote_tweet_url = url
-        preview_description += """\
-<span class="verb">quote</span>
-<a href="%s">this tweet</a>:<br>
-%s
-<br>and """ % (url, self.embed_post(att))
+        preview_description += f"""<span class="verb">quote</span>
+<a href="{url}">this tweet</a>:<br>
+{self.embed_post(att)}
+<br>and """
         break
 
     content = self._content_for_create(
@@ -759,8 +763,8 @@ class Twitter(source.Source):
       parsed = urllib.parse.urlparse(base_url)
       parts = parsed.path.split('/')
       if len(parts) < 2 or not parts[1]:
-        raise ValueError('Could not determine author of in-reply-to URL %s' % base_url)
-      reply_to_prefix = '@%s ' % parts[1].lower()
+        raise ValueError(f'Could not determine author of in-reply-to URL {base_url}')
+      reply_to_prefix = f'@{parts[1].lower()} '
       if content.lower().startswith(reply_to_prefix):
         content = content[len(reply_to_prefix):]
 
@@ -795,10 +799,9 @@ class Twitter(source.Source):
           '<a href="http://indiewebcamp.com/rel-syndication">rel-syndication</a> link to Twitter.')
 
       if preview:
-        preview_description += """\
-<span class="verb">favorite</span>
-<a href="%s">this tweet</a>:
-%s""" % (base_url, self.embed_post(base_obj))
+        preview_description += f"""<span class="verb">favorite</span>
+<a href="{base_url}">this tweet</a>:
+{self.embed_post(base_obj)}"""
         return source.creation_result(description=preview_description)
       else:
         data = urllib.parse.urlencode({'id': base_id})
@@ -815,10 +818,9 @@ class Twitter(source.Source):
           '<a href="http://indiewebcamp.com/rel-syndication">rel-syndication</a> link to Twitter.')
 
       if preview:
-          preview_description += """\
-<span class="verb">retweet</span>
-<a href="%s">this tweet</a>:
-%s""" % (base_url, self.embed_post(base_obj))
+          preview_description += f"""<span class="verb">retweet</span>
+<a href="{base_url}">this tweet</a>:
+{self.embed_post(base_obj)}"""
           return source.creation_result(description=preview_description)
       else:
         data = urllib.parse.urlencode({'id': base_id})
@@ -831,9 +833,8 @@ class Twitter(source.Source):
       data = [('status', content)]
 
       if is_reply and base_url:
-        preview_description += """\
-<span class="verb">@-reply</span> to <a href="%s">this tweet</a>:
-%s""" % (base_url, self.embed_post(base_obj))
+        preview_description += f"""<span class="verb">@-reply</span> to <a href="{base_url}">this tweet</a>:
+{self.embed_post(base_obj)}"""
         data.extend([
           ('in_reply_to_status_id', base_id),
           ('auto_populate_reply_metadata', 'true'),
@@ -842,8 +843,7 @@ class Twitter(source.Source):
         preview_description += '<span class="verb">tweet</span>:'
 
       if video_url:
-        preview_content += ('<br /><br /><video controls src="%s"><a href="%s">'
-                            'this video</a></video>' % (video_url, video_url))
+        preview_content += f'<br /><br /><video controls src="{video_url}"><a href="{video_url}">this video</a></video>'
         if not preview:
           ret = self.upload_video(video_url)
           if isinstance(ret, source.CreationResult):
@@ -854,10 +854,9 @@ class Twitter(source.Source):
         num = len(images)
         if num > MAX_MEDIA:
           images = images[:MAX_MEDIA]
-          logging.warning('Found %d photos! Only using the first %d: %r',
-                          num, MAX_MEDIA, images)
+          logger.warning(f'Found {num} photos! Only using the first {MAX_MEDIA}: {images}')
         preview_content += '<br /><br />' + ' &nbsp; '.join(
-          '<img src="%s" alt="%s" />' % (img.get('url'), img.get('displayName', ''))
+          f"<img src=\"{img.get('url')}\" alt=\"{img.get('displayName', '')}\" />"
                                          for img in images)
         if not preview:
           ret = self.upload_images(images)
@@ -867,8 +866,7 @@ class Twitter(source.Source):
 
       if lat and lng:
         preview_content += (
-          '<div>at <a href="https://maps.google.com/maps?q=%s,%s">'
-          '%s, %s</a></div>' % (lat, lng, lat, lng))
+          f'<div>at <a href="https://maps.google.com/maps?q={lat},{lng}">{lat}, {lng}</a></div>')
         data.extend([
           ('lat', lat),
           ('long', lng),
@@ -883,8 +881,8 @@ class Twitter(source.Source):
     else:
       return source.creation_result(
         abort=False,
-        error_plain='Cannot publish type=%s, verb=%s to Twitter' % (type, verb),
-        error_html='Cannot publish type=%s, verb=%s to Twitter' % (type, verb))
+        error_plain=f'Cannot publish type={type}, verb={verb} to Twitter',
+        error_html=f'Cannot publish type={type}, verb={verb} to Twitter')
 
     id_str = resp.get('id_str')
     if id_str:
@@ -928,7 +926,7 @@ class Twitter(source.Source):
                                 files={'media': image_resp},
                                 headers=headers)
       resp.raise_for_status()
-      logging.info('Got: %s', resp.text)
+      logger.info(f'Got: {resp.text}')
       media_id = source.load_json(resp.text, API_UPLOAD_MEDIA)['media_id_string']
       ids.append(media_id)
 
@@ -942,7 +940,7 @@ class Twitter(source.Source):
           json={'media_id': media_id, 'alt_text': {'text': alt}},
           headers=headers)
         resp.raise_for_status()
-        logging.info('Got: %s', resp.text)
+        logger.info(f'Got: {resp.text}')
 
     return ids
 
@@ -1019,7 +1017,7 @@ class Twitter(source.Source):
       delay = min(info.get('check_after_secs', 0),
                   API_MEDIA_STATUS_MAX_DELAY_SECS)
       total_delay += delay
-      logging.info(f'video still processing, waiting {delay}s to check status')
+      logger.info(f'video still processing, waiting {delay}s to check status')
       sleep_fn(delay)
 
       params = urllib.parse.urlencode({
@@ -1051,19 +1049,17 @@ class Twitter(source.Source):
     if not type:
       type, _ = mimetypes.guess_type(url)
     if type and type not in types:
-      msg = 'Twitter only supports %s; %s looks like %s' % (
-        label, util.pretty_link(url), type)
+      msg = f'Twitter only supports {label}; {util.pretty_link(url)} looks like {type}'
       return source.creation_result(abort=True, error_plain=msg, error_html=msg)
 
     length = resp.headers.get('Content-Length')
     if not util.is_int(length):
-      msg = "Couldn't determine the size of %s" % util.pretty_link(url)
+      msg = f"Couldn't determine the size of {util.pretty_link(url)}"
       return source.creation_result(abort=True, error_plain=msg, error_html=msg)
 
     length = int(length)
     if int(length) > max_size:
-      msg = "Your %.2fMB file is larger than Twitter's %dMB limit: %s" % (
-        length // MB, max_size // MB, util.pretty_link(url))
+      msg = f"Your {length // MB:.2f}MB file is larger than Twitter's {max_size // MB}MB limit: {util.pretty_link(url)}"
       return source.creation_result(abort=True, error_plain=msg, error_html=msg)
 
   def delete(self, id):
@@ -1086,10 +1082,9 @@ class Twitter(source.Source):
     Returns: CreationResult
     """
     url = self.status_url(self.username or '_', id)
-    return source.creation_result(description="""\
-<span class="verb">delete</span>
-<a href="%s">this tweet</a>:
-%s""" % (url, self.embed_post({'url': url})))
+    return source.creation_result(description=f"""<span class="verb">delete</span>
+<a href="{url}">this tweet</a>:
+{self.embed_post({'url': url})}""")
 
   def urlopen(self, url, parse_response=True, **kwargs):
     """Wraps :func:`urllib2.urlopen()` and adds an OAuth signature."""
@@ -1116,7 +1111,7 @@ class Twitter(source.Source):
           code, body = util.interpret_http_exception(e)
           if code is None or int(code) not in (500, 501, 502):
             raise
-        logging.info('Twitter API call failed! Retrying...')
+        logger.info('Twitter API call failed! Retrying...')
 
     # last try. if it deadlines, let the exception bubble up.
     return request()
@@ -1147,7 +1142,7 @@ class Twitter(source.Source):
           parsed[2] = '/'.join(parts[:-2])
           base_obj['url'] = urllib.parse.urlunparse(parsed)
       except BaseException as e:
-        logging.error(
+        logger.error(
           "Couldn't parse object URL %s : %s. Falling back to default logic.",
           url, e)
 
@@ -1562,8 +1557,8 @@ class Twitter(source.Source):
     url = obj_url = self.tweet_url(tweet)
 
     if liker_id:
-      id = self.tag_uri('%s_favorited_by_%s' % (tweet_id, liker_id))
-      url += '#favorited-by-%s' % liker_id
+      id = self.tag_uri(f'{tweet_id}_favorited_by_{liker_id}')
+      url += f'#favorited-by-{liker_id}'
 
     return self.postprocess_object({
         'id': id,
@@ -1600,11 +1595,11 @@ class Twitter(source.Source):
 
   def user_url(self, username):
     """Returns the Twitter URL for a given user."""
-    return 'https://%s/%s' % (self.DOMAIN, username)
+    return f'https://{self.DOMAIN}/{username}'
 
   def status_url(self, username, id):
     """Returns the Twitter URL for a tweet from a given user with a given id."""
-    return '%s/status/%s' % (self.user_url(username), id)
+    return f'{self.user_url(username)}/status/{id}'
 
   def tweet_url(self, tweet):
     """Returns the Twitter URL for a tweet given a tweet object."""
@@ -1614,4 +1609,4 @@ class Twitter(source.Source):
   @staticmethod
   def _validate_id(id):
       if not util.is_int(id):
-        raise ValueError('Twitter ids must be integers; got %s' % id)
+        raise ValueError(f'Twitter ids must be integers; got {id}')
