@@ -23,6 +23,8 @@ from .models import BaseAuth
 from .webutil import appengine_info, flask_util, util
 from .webutil.util import json_dumps, json_loads
 
+logger = logging.getLogger(__name__)
+
 # https://docs.joinmastodon.org/api/oauth-scopes/
 ALL_SCOPES = (
   'read',
@@ -80,12 +82,12 @@ def _encode_state(app, state):
     'app_key': app.key.urlsafe().decode(),
     'state': quote_plus(state) if state else '',
   })
-  logging.debug('Encoding wrapper state: %r', wrapped)
+  logger.debug(f'Encoding wrapper state: {wrapped!r}')
   return wrapped
 
 
 def _decode_state(state):
-  logging.debug('Decoding wrapper state: %r', state)
+  logger.debug(f'Decoding wrapper state: {state!r}')
   decoded = json_loads(state)
   return decoded['app_key'], unquote(decoded['state'])
 
@@ -221,18 +223,18 @@ class Start(views.Start):
       resp = util.requests_get(urljoin(instance, INSTANCE_API))
       resp.raise_for_status()
     except requests.RequestException:
-      logging.info('Error', exc_info=True)
+      logger.info('Error', exc_info=True)
       resp = None
 
     is_json = resp and resp.headers.get('Content-Type', '').strip().startswith(
       'application/json')
     if is_json:
-      logging.info(resp.text)
+      logger.info(resp.text)
     if (not resp or not resp.ok or not is_json or
         not self._version_ok(resp.json().get('version'))):
-      msg = "%s doesn't look like a %s instance." % (instance, self.LABEL)
-      logging.info(resp)
-      logging.info(msg)
+      msg = f"{instance} doesn't look like a {self.LABEL} instance."
+      logger.info(resp)
+      logger.info(msg)
       raise ValueError(msg)
 
     # if we got redirected, update instance URL
@@ -254,7 +256,7 @@ class Start(views.Start):
       app.instance_info = resp.text
       app.put()
 
-    logging.info('Starting OAuth for %s instance %s', self.LABEL, instance)
+    logger.info(f'Starting OAuth for {self.LABEL} instance {instance}')
     app_data = json_loads(app.data)
     return urljoin(instance, AUTH_CODE_API % {
       'client_id': app_data['client_id'],
@@ -276,8 +278,7 @@ class Start(views.Start):
 
     Returns: APP_CLASS
     """
-    logging.info("first time we've seen %s instance %s with app %s %s! "
-                 "registering an API app.", self.LABEL, instance, app_name, app_url)
+    logger.info(f"first time we've seen {self.LABEL} instance {instance} with app {app_name} {app_url}! registering an API app.")
 
     redirect_uris = {urljoin(request.host_url, path)
                      for path in set(self.REDIRECT_PATHS)}
@@ -301,7 +302,7 @@ class Start(views.Start):
     resp.raise_for_status()
 
     app_data = json_loads(resp.text)
-    logging.info('Got %s', app_data)
+    logger.info(f'Got {app_data}')
     app = self.APP_CLASS(instance=instance, app_name=app_name,
                          app_url=app_url, data=json_dumps(app_data))
     app.put()
@@ -309,8 +310,8 @@ class Start(views.Start):
 
   @classmethod
   def button_html(cls, *args, **kwargs):
-    kwargs['form_extra'] = kwargs.get('form_extra', '') + """
-<input type="url" name="instance" class="form-control" placeholder="%s instance" scheme="https" required style="width: 135px; height: 50px; display:inline;" />""" % cls.LABEL
+    kwargs['form_extra'] = kwargs.get('form_extra', '') + f"""
+<input type="url" name="instance" class="form-control" placeholder="{cls.LABEL} instance" scheme="https" required style="width: 135px; height: 50px; display:inline;" />"""
     return super(Start, cls).button_html(
       *args, input_style='background-color: #EBEBEB; padding: 5px', **kwargs)
 
@@ -327,7 +328,7 @@ class Callback(views.Callback):
       # user_cancelled_login and user_cancelled_authorize are non-standard.
       # https://tools.ietf.org/html/rfc6749#section-4.1.2.1
       if error in ('user_cancelled_login', 'user_cancelled_authorize', 'access_denied'):
-        logging.info('User declined: %s', request.values.get('error_description'))
+        logger.info(f"User declined: {request.values.get('error_description')}")
         state = request.values.get('state')
         if state:
           _, state = _decode_state(state)
@@ -357,14 +358,14 @@ class Callback(views.Callback):
       headers={'Content-Type': 'application/x-www-form-urlencoded'})
     resp.raise_for_status()
     resp_json = resp.json()
-    logging.debug('Access token response: %s', resp_json)
+    logger.debug(f'Access token response: {resp_json}')
     if resp_json.get('error'):
       flask_util.error(resp_json)
 
     access_token = resp_json['access_token']
     user = self.AUTH_CLASS(app=app.key, access_token_str=access_token).get(VERIFY_API).json()
-    logging.debug('User: %s', user)
-    address = '@%s@%s' % (user['username'], urlparse(app.instance).netloc)
+    logger.debug(f'User: {user}')
+    address = f"@{user['username']}@{urlparse(app.instance).netloc}"
     auth = self.AUTH_CLASS(id=address, app=app.key, access_token_str=access_token,
                            user_json=json_dumps(user))
     auth.put()
