@@ -14,6 +14,8 @@ from . import models, twitter_auth, views
 from .webutil import flask_util, util
 from .webutil.util import json_dumps, json_loads
 
+logger = logging.getLogger(__name__)
+
 API_ACCOUNT_URL = 'https://api.twitter.com/1.1/account/verify_credentials.json'
 
 
@@ -100,15 +102,15 @@ class Start(views.Start):
   def __init__(self, to_path, scopes=None, access_type=None):
     super().__init__(to_path, scopes=scopes)
     assert access_type in (None, 'read', 'write'), \
-        'access_type must be "read" or "write"; got %r' % access_type
+        f'access_type must be "read" or "write"; got {access_type!r}'
     self.access_type = access_type
 
   def redirect_url(self, state=None):
     assert twitter_auth.TWITTER_APP_KEY and twitter_auth.TWITTER_APP_SECRET, \
       "Please fill in the twitter_app_key and twitter_app_secret files in your app's root directory."
-    auth = tweepy.OAuthHandler(twitter_auth.TWITTER_APP_KEY,
-                               twitter_auth.TWITTER_APP_SECRET,
-                               self.to_url(state=state))
+    auth = tweepy.OAuth1UserHandler(twitter_auth.TWITTER_APP_KEY,
+                                    twitter_auth.TWITTER_APP_SECRET,
+                                    callback=self.to_url(state=state))
 
     # signin_with_twitter=True returns /authenticate instead of /authorize so
     # that Twitter doesn't prompt the user for approval if they've already
@@ -128,7 +130,7 @@ class Start(views.Start):
     models.OAuthRequestToken(id=auth.request_token['oauth_token'],
                              token_secret=auth.request_token['oauth_token_secret']
                              ).put()
-    logging.info('Generated request token, redirecting to Twitter: %s', auth_url)
+    logger.info(f'Generated request token, redirecting to Twitter: {auth_url}')
     return auth_url
 
 
@@ -147,11 +149,11 @@ class Callback(views.Callback):
     # Lookup the request token
     request_token = models.OAuthRequestToken.get_by_id(oauth_token)
     if request_token is None:
-      flask_util.error('Invalid oauth_token: %s' % oauth_token)
+      flask_util.error(f'Invalid oauth_token: {oauth_token}')
 
     # Rebuild the auth view
-    auth = tweepy.OAuthHandler(twitter_auth.TWITTER_APP_KEY,
-                               twitter_auth.TWITTER_APP_SECRET)
+    auth = tweepy.OAuth1UserHandler(twitter_auth.TWITTER_APP_KEY,
+                                    twitter_auth.TWITTER_APP_SECRET)
     auth.request_token = {'oauth_token': request_token.key.string_id(),
                           'oauth_token_secret': request_token.token_secret}
 
