@@ -107,6 +107,11 @@ try:
 except ImportError:
   tweepy = None
 
+logger = logging.getLogger(__name__)
+
+# set with set_user_agent()
+user_agent = 'webutil (https://github.com/snarfed/webutil)'
+
 EPOCH = datetime.datetime.utcfromtimestamp(0)
 EPOCH_ISO = EPOCH.isoformat()
 # from https://stackoverflow.com/a/53140944/186123
@@ -223,7 +228,7 @@ def to_xml(value):
     for key, vals in sorted(value.items()):
       if not isinstance(vals, (list, tuple)):
         vals = [vals]
-      elems.extend('<%s>%s</%s>' % (key, to_xml(val), key) for val in vals)
+      elems.extend(f'<{key}>{to_xml(val)}</{key}>' for val in vals)
     return '\n' + '\n'.join(elems) + '\n'
   else:
     if value is None:
@@ -346,7 +351,7 @@ def tag_uri(domain, name, year=None):
 
   Background on tag URIs: http://taguri.org/
   """
-  year = ',%s' % year if year else ''
+  year = f',{year}' if year else ''
   return f'tag:{domain}{year}:{name}'
 
 
@@ -381,24 +386,22 @@ def parse_acct_uri(uri, hosts=None):
   """
   parsed = urlparse(uri)
   if parsed.scheme and parsed.scheme != 'acct':
-    raise ValueError('Acct URI %s has unsupported scheme: %s' %
-                     (uri, parsed.scheme))
+    raise ValueError(f'Acct URI {uri} has unsupported scheme: {parsed.scheme}')
 
   try:
     username, host = parsed.path.split('@')
     assert host
   except (ValueError, AssertionError):
-    raise ValueError('Bad acct URI: %s' % uri)
+    raise ValueError(f'Bad acct URI: {uri}')
 
   if hosts is not None and host not in hosts:
-    raise ValueError('Acct URI %s has unsupported host %s; expected %r.' %
-                     (uri, host, hosts))
+    raise ValueError(f'Acct URI {uri} has unsupported host {host}; expected {hosts!r}.')
 
   return username, host
 
 
 def favicon_for_url(url):
-  return 'http://%s/favicon.ico' % urlparse(url).netloc
+  return f'http://{urlparse(url).netloc}/favicon.ico'
 
 
 FULL_HOST_RE = re.compile(HOST_RE + '$')
@@ -668,7 +671,7 @@ def linkify(text, pretty=False, skip_bare_cc_tlds=False, **kwargs):
     if pretty:
       result.append(pretty_link(href, **kwargs))
     else:
-      result.append('<a href="%s">%s</a>' % (href, url))
+      result.append(f'<a href="{href}">{url}</a>')
   result.append(splits[-1])
   return ''.join(result)
 
@@ -728,9 +731,9 @@ def pretty_link(url, text=None, keep_host=True, glyphicon=None, attrs=None,
 
   escaped_text = saxutils.escape(text)
   if glyphicon is not None:
-    escaped_text += ' <span class="glyphicon glyphicon-%s"></span>' % glyphicon
+    escaped_text += f' <span class="glyphicon glyphicon-{glyphicon}"></span>'
 
-  attr_str = (''.join('%s="%s" ' % (attr, val) for attr, val in list(attrs.items()))
+  attr_str = (''.join(f'{attr}="{val}" ' for attr, val in list(attrs.items()))
               if attrs else '')
   target = 'target="_blank" ' if new_tab else ''
   return ('<a %s%shref="%s">%s</a>' %
@@ -848,9 +851,9 @@ def to_iso8601_duration(input):
   Raises: :class:`TypeError` if delta is not a :class:`datetime.timedelta`
   """
   if not isinstance(input, datetime.timedelta):
-    raise TypeError('Expected datetime.timedelta, got %s' % input.__class__)
+    raise TypeError(f'Expected datetime.timedelta, got {input.__class__}')
 
-  return 'P%sDT%sS' % (input.days, input.seconds)
+  return f'P{input.days}DT{input.seconds}S'
 
 
 def maybe_iso8601_to_rfc3339(input):
@@ -996,10 +999,10 @@ def get_required_param(handler, name):
   try:
     val = handler.request.get(name)
   except (UnicodeDecodeError, UnicodeEncodeError) as e:
-    handler.abort(400, "Couldn't decode query parameters as UTF-8: %s" % e)
+    handler.abort(400, f"Couldn't decode query parameters as UTF-8: {e}")
 
   if not val:
-    handler.abort(400, 'Missing required parameter: %s' % name)
+    handler.abort(400, f'Missing required parameter: {name}')
 
   return val
 
@@ -1077,9 +1080,9 @@ def encode_oauth_state(obj):
     a string
   """
   if not isinstance(obj, dict):
-    raise TypeError('Expected dict, got %s' % obj.__class__)
+    raise TypeError(f'Expected dict, got {obj.__class__}')
 
-  logging.debug('encoding state %r', obj)
+  logger.debug(f'encoding state {obj!r}')
   return urllib.parse.quote_plus(json_dumps(trim_nulls(obj), sort_keys=True))
 
 
@@ -1092,17 +1095,17 @@ def decode_oauth_state(state):
   Returns: dict
   """
   if not isinstance(state, str) and state is not None:
-    raise TypeError('Expected str, got %s' % state.__class__)
+    raise TypeError(f'Expected str, got {state.__class__}')
 
-  logging.debug('decoding state %r', state)
+  logger.debug(f'decoding state {state!r}', )
   try:
     obj = json_loads(urllib.parse.unquote_plus(state)) if state else {}
   except ValueError:
-    logging.error(f'Invalid value for state parameter: {state}', stack_info=True)
+    logger.error(f'Invalid value for state parameter: {state}', stack_info=True)
     abort(400, f'Invalid value for state parameter: {state}')
 
   if not isinstance(obj, dict):
-    logging.error('got a non-dict state parameter %s', state)
+    logger.error(f'got a non-dict state parameter {state}')
     return {}
 
   return obj
@@ -1261,15 +1264,16 @@ def interpret_http_exception(exception):
     code = e.error_code
     body = e.msg
 
-  elif tweepy and isinstance(e, tweepy.TweepError):
-    code = '429' if isinstance(e, tweepy.RateLimitError) else '400'
-    body = e.reason
+  elif tweepy and isinstance(e, tweepy.HTTPException):
+    code = '429' if isinstance(e, tweepy.TooManyRequests) else '400'
+    body = e.response.text
 
   elif apiclient and isinstance(e, apiclient.errors.HttpError):
     code = e.resp.status
-    body = e.content.decode('utf-8')
+    body = e.response.text
 
-  elif AccessTokenRefreshError and isinstance(e, AccessTokenRefreshError):
+  elif ((AccessTokenRefreshError and isinstance(e, AccessTokenRefreshError)) or
+        (prawcore and isinstance(e, prawcore.exceptions.OAuthException))):
     body = str(e)
     if body.startswith('invalid_grant'):
       code = '401'
@@ -1288,7 +1292,7 @@ def interpret_http_exception(exception):
     code = str(code)
   orig_code = code
   if code or body:
-    logging.warning('Error %s, response body: %s', code, repr(body))
+    logger.warning(f'Error {code}, response body: {body!r}')
 
   if isinstance(body, bytes):
     # good faith effort to decode as UTF-8 or ASCII
@@ -1372,7 +1376,7 @@ def interpret_http_exception(exception):
       body = str(e)
 
   if orig_code != code:
-    logging.info('Converting code %s to %s', orig_code, code)
+    logger.info(f'Converting code {orig_code} to {code}')
 
   return code, body
 
@@ -1426,7 +1430,7 @@ def is_connection_failure(exception):
     # TODO: exc_info might not be for exception, e.g. if the json_loads() in
     # interpret_http_exception() fails. need to pass through the whole
     # sys.exc_info() tuple here, not just the exception object.
-    logging.info('Connection failure: %s' % exception, stack_info=True)
+    logger.info(f'Connection failure: {exception}', stack_info=True)
     return True
 
   return False
@@ -1502,30 +1506,51 @@ def json_dumps(*args, **kwargs):
   return json.dumps(*args, **kwargs)
 
 
+def set_user_agent(val):
+  """Sets the user agent to be sent in :func:`urlopen` and :func:`requests_fn`.
+
+  Args:
+    val: str
+  """
+  global user_agent
+  user_agent = val
+
+
 def urlopen(url_or_req, *args, **kwargs):
-  """Wraps :func:`urllib.request.urlopen` and logs the HTTP method and URL."""
+  """Wraps :func:`urllib.request.urlopen` and logs the HTTP method and URL.
+
+  Use :func:`set_user_agent` to change the User-Agent header to be sent.
+  """
   data = kwargs.get('data')
   if isinstance(data, str):
     kwargs['data'] = data.encode()
 
   if url_or_req.__class__.__name__ == 'Request':
+    req = url_or_req
     if data is None:
-      data = url_or_req.data
+      data = req.data
       if isinstance(data, str):
-        url_or_req.data = data.encode()
-    url = url_or_req.get_full_url()
+        req.data = data.encode()
+    url = req.get_full_url()
   else:
     url = url_or_req
+    req = urllib.request.Request(url)
 
-  logging.info('urlopen %s %s %s', 'GET' if data is None else 'POST', url,
-               _prune(kwargs))
+  if not req.has_header('User-Agent'):
+    global user_agent
+    req.add_header('User-Agent', user_agent)
+
+  method = 'GET' if data is None else 'POST'
+  logger.info(f'urlopen {method} {url} {_prune(kwargs)}')
   kwargs.setdefault('timeout', HTTP_TIMEOUT)
-  return urllib.request.urlopen(url_or_req, *args, **kwargs)
+  return urllib.request.urlopen(req, *args, **kwargs)
 
 
 def requests_fn(fn):
   """Wraps requests.* and logs the HTTP method and URL.
 
+  Use :func:`set_user_agent` to change the User-Agent header to be sent.
+
   Args:
     fn: 'get', 'head', or 'post'
     gateway: boolean, whether this is in a HTTP gateway request handler context.
@@ -1535,18 +1560,22 @@ def requests_fn(fn):
       :class:`werkzeug.exceptions.BadGateway` (HTTP 502).
   """
   def call(url, *args, **kwargs):
-    logging.info('requests.%s %s %s', fn, url, _prune(kwargs))
+    logger.info(f'requests.{fn} {url} {_prune(kwargs)}')
 
     gateway = kwargs.pop('gateway', None)
     kwargs.setdefault('timeout', HTTP_TIMEOUT)
     # stream to short circuit on too-long response bodies (below)
     kwargs.setdefault('stream', True)
 
+    if kwargs.get('headers') is None:
+      kwargs['headers'] =  {}
+    kwargs['headers'].setdefault('User-Agent', user_agent)
+
     try:
       # use getattr so that stubbing out with mox still works
       resp = getattr(requests, fn)(url, *args, **kwargs)
       if gateway:
-        logging.info(f'Received {resp.status_code}: {"" if resp.ok else resp.text[:500]}')
+        logger.info(f'Received {resp.status_code}: {"" if resp.ok else resp.text[:500]}')
         resp.raise_for_status()
     except (ValueError, requests.URLRequired) as e:
       if isinstance(e, requests.exceptions.InvalidURL):
@@ -1564,11 +1593,11 @@ def requests_fn(fn):
 
       if gateway:
         msg = f'Bad URL {url} : {e}'
-        logging.warning(msg)
+        logger.warning(msg)
         # this format_exc with tb None below, instead of passing exc_info=True
         # above, prevents the 'Traceback (most recent call last):' prefix that
         # triggers Stackdriver Error Reporting
-        logging.warning('\n'.join(traceback.format_tb(sys.exc_info()[2])))
+        logger.warning('\n'.join(traceback.format_tb(sys.exc_info()[2])))
         abort(400, msg)
       raise
 
@@ -1577,13 +1606,13 @@ def requests_fn(fn):
         msg = str(e)
         if e.response is not None:
           msg += f' ; {e.response.text}'
-        logging.warning(msg)
-        logging.warning('\n'.join(traceback.format_tb(sys.exc_info()[2])))
+        logger.warning(msg)
+        logger.warning('\n'.join(traceback.format_tb(sys.exc_info()[2])))
         abort(502, msg)
       raise
 
     if url != resp.url:
-      logging.info('Redirected to %s', resp.url)
+      logger.info(f'Redirected to {resp.url}')
 
     # check response size for text/ and application/ Content-Types
     type = resp.headers.get('Content-Type', '')
@@ -1596,13 +1625,12 @@ def requests_fn(fn):
       if length > MAX_HTTP_RESPONSE_SIZE:
         resp.close()
         resp.status_code = HTTP_RESPONSE_TOO_BIG_STATUS_CODE
-        resp._text = ('Content-Length %s is larger than our limit %s.' %
-                      (length, MAX_HTTP_RESPONSE_SIZE))
+        resp._text = f'Content-Length {length} is larger than our limit {MAX_HTTP_RESPONSE_SIZE}.'
         resp._content = resp._text.encode('utf-8')
         if gateway:
           resp.raise_for_status()
 
-    logging.info(f'Received {resp.status_code}')
+    logger.info(f'Received {resp.status_code}')
 
     return resp
 
@@ -1677,7 +1705,7 @@ def follow_redirects(url, **kwargs):
   except AssertionError:
     raise
   except BaseException as e:
-    logging.warning("Couldn't resolve URL %s : %s", url, e)
+    logger.warning(f"Couldn't resolve URL {url} : {e}")
     resolved = requests.Response()
     resolved.url = url
     resolved.status_code = 499  # not standard. i made this up.
@@ -1685,9 +1713,9 @@ def follow_redirects(url, **kwargs):
   try:
     resolved.raise_for_status()
     if resolved.url != url:
-      logging.debug('Resolved %s to %s', url, resolved.url)
+      logger.debug(f'Resolved {url} to {resolved.url}')
   except BaseException as e:
-    logging.warning("Couldn't resolve URL %s : %s", url, e)
+    logger.warning(f"Couldn't resolve URL {url}: {resolved.url}")
 
   content_type = resolved.headers.get('content-type')
   if (not resolved.ok or
@@ -1778,7 +1806,7 @@ class UrlCanonicalizer(object):
     if domain.startswith('www.'):
       domain = domain[4:]
     if self.subdomain and domain.count('.') == 1:
-      domain = '%s.%s' % (self.subdomain, domain)
+      domain = f'{self.subdomain}.{domain}'
 
     scheme = self.scheme or parsed.scheme
     query = parsed.query if self.query else ''
@@ -1927,7 +1955,7 @@ def parse_mf2(input, url=None, id=None):
     input = parse_html(input)
 
   if id:
-    logging.info('Extracting and parsing just DOM element %s', id)
+    logger.info(f'Extracting and parsing just DOM element {id}')
     input = input.find(id=id)
     if not input:
       return None
